#
# spec file for package java-10-openjdk
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{!?aarch64:%global aarch64 aarch64 arm64 armv8}
%{!?arm6:%global arm6 armv3l armv4b armv4l armv4tl armv5b armv5l armv5teb armv5tel armv5tejl armv6l armv6hl}
%global jit_arches %{ix86} x86_64 ppc64 ppc64le %{aarch64} %{arm} s390x
%global debug 0
%global buildoutputdir build
# Convert an absolute path to a relative path.  Each symbolic link is
# specified relative to the directory in which it is installed so that
# it will resolve properly within chrooted installations.
%global script 'use File::Spec; print File::Spec->abs2rel($ARGV[0], $ARGV[1])'
%global abs2rel perl -e %{script}
%global syslibdir       %{_libdir}
%global archname        %{name}
# Standard JPackage naming and versioning defines.
%global featurever      10
%global interimver      0
%global updatever       2
%global patchver        0
%global datever         2018-07-17
%global buildver        13
%global hg_project      jdk-updates
%global hg_repository   jdk10u
%global hg_revision     45b1d041a4ef
%global icedtea_sound_version 1.0.1
%global java_atk_wrapper_version 0.33.2
# priority must be 6 digits in total
%global priority        2005
%global javaver         %{featurever}
# Standard JPackage directories and symbolic links.
%global sdklnk          java-%{javaver}-openjdk
%global archname        %{sdklnk}
%global jrelnk          jre-%{javaver}-openjdk
%global jrebindir       %{_jvmdir}/%{jrelnk}/bin
%global sdkdir          %{sdklnk}-%{javaver}
%global sdkbindir       %{_jvmdir}/%{sdklnk}/bin
# Prevent brp-java-repack-jars from being run.
%global __jar_repack 0
# cacert symlink
%global cacerts  %{_jvmdir}/%{sdkdir}/lib/security/cacerts
# real file made by update-ca-certificates
%global javacacerts %{_var}/lib/ca-certificates/java-cacerts
%global bootcycle 1
# turn zero on non jit arches by default
%ifnarch %{jit_arches}
%global _with_zero 1
%endif
%if %{debug}
%global debugbuild slowdebug
%else
%global debugbuild release
%endif
%if %{bootcycle}
%global imagesdir bootcycle-build/images
%global imagestarget bootcycle-images all
%else
%global imagesdir images
%global imagestarget all
%endif
# bnc#542545
# 32-bit versus 64-bit specific provides:
%ifarch %{ix86} ppc s390
%global bits 32
%endif
%ifarch x86_64 ia64 s390x
%global bits 64
%endif
%if 0%{?__isa_bits}
%global bits %{__isa_bits}
%endif
# Turn on/off some features depending on openSUSE version
%if 0%{?suse_version} > 1320
%global with_system_pcsc 1
%else
%global with_system_pcsc 0
%endif
%global with_pulseaudio 1
%bcond_with zero
%if ! %{with zero}
%ifarch x86_64
%global _with_aot 1
%endif
%endif
%bcond_with aot
%if ! %{with zero}
%global with_systemtap 1
%else
%global with_systemtap 0
%endif
%if %{with_systemtap}
%global tapsetroot      %{_datadir}/systemtap
%global tapsetdir %{tapsetroot}/tapset/%{_build_cpu}
%endif
%if %{with_systemtap}
# Where to install systemtap tapset (links)
# We would like these to be in a package specific subdir,
# but currently systemtap doesn't support that, so we have to
# use the root tapset dir for now. To distinquish between 64
# and 32 bit architectures we place the tapsets under the arch
# specific dir (note that systemtap will only pickup the tapset
# for the primary arch for now). Systemtap uses the machine name
# aka build_cpu as architecture specific directory name.
%global tapsetroot %{_datadir}/systemtap
%global tapsetdir %{tapsetroot}/tapset/%{_build_cpu}
%endif
Name:           java-10-openjdk
Version:        %{featurever}.%{interimver}.%{updatever}.%{patchver}
Release:        lp151.2.3.2
Summary:        OpenJDK 10 Runtime Environment
License:        Apache-1.1 AND Apache-2.0 AND GPL-1.0-or-later AND GPL-2.0-only AND GPL-2.0-with-classpath-exception AND LGPL-2.0-only AND MPL-1.0 AND MPL-1.1 AND SUSE-Public-Domain AND W3C
Group:          Development/Languages/Java
Url:            http://openjdk.java.net/
# Sources from upstream OpenJDK10 project.
Source0:        http://hg.openjdk.java.net/%{hg_project}/%{hg_repository}/archive/%{hg_revision}.tar.bz2
# Accessibility support
Source8:        ftp://ftp.gnome.org/pub/GNOME/sources/java-atk-wrapper/0.33/java-atk-wrapper-%{java_atk_wrapper_version}.tar.xz
# Pulseaudio support
Source9:        http://icedtea.classpath.org/download/source/icedtea-sound-%{icedtea_sound_version}.tar.xz
# Systemtap tapsets. Zipped up to keep it small.
Source10:       systemtap-tapset.tar.xz
# Desktop files. Adapated from IcedTea.
Source11:       jconsole.desktop.in
# nss configuration file
Source13:       nss.cfg
# Ensure we aren't using the limited crypto policy
Source14:       TestCryptoLevel.java
# Ensure ECDSA is working
Source15:       TestECDSA.java
# Fresh config.guess and config.sub files
# wget -O config.guess 'http://git.savannah.gnu.org/gitweb/?p=config.git;a=blob_plain;f=config.guess;hb=HEAD'
Source100:      config.guess
# wget -O config.sub 'http://git.savannah.gnu.org/gitweb/?p=config.git;a=blob_plain;f=config.sub;hb=HEAD'
Source101:      config.sub
# RPM/distribution specific patches
Patch1:         icedtea-sound-1.0.1-jdk9.patch
Patch2:         icedtea-sound-soundproperties.patch
# Restrict access to java-atk-wrapper classes
Patch3:         java-atk-wrapper-security.patch
# RHBZ 808293
Patch4:         PStack-808293.patch
# Allow multiple initialization of PKCS11 libraries
Patch5:         multiple-pkcs11-library-init.patch
# Fix instantiation of VM on ZERO
Patch8:         zero-ranges.patch
# From icedtea: Increase default memory limits
Patch10:        memory-limits.patch
# Fix use of unintialized memory in adlc parser
Patch12:        adlc-parser.patch
# Fix: implicit-pointer-decl
Patch13:        implicit-pointer-decl.patch
#
Patch14:        missing-return.patch
#
Patch15:        system-pcsclite.patch
#
# OpenJDK specific patches
#
Patch100:       s390-java-opts.patch
Patch101:       s390-size_t.patch
#
Patch102:       sorted-diff.patch
Patch103:       jdk10-gcc6.patch
#
Patch200:       ppc_stack_overflow_fix.patch
Patch201:       fix_armv6_build.patch
#
Patch300:       java-10-openjdk-linuxfilestore.patch
Patch302:       disable-doclint-by-default.patch
Patch303:       alternative-tzdb_dat.patch
#
Patch400:       jaw-misc.patch
Patch401:       jaw-jdk10.patch
Patch800:       java10-improved-fonts.patch
BuildRequires:  alsa-lib-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bc
BuildRequires:  binutils
BuildRequires:  cups-devel
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  fontconfig
BuildRequires:  freetype2-devel
BuildRequires:  gcc-c++
BuildRequires:  giflib-devel
BuildRequires:  gtk2-devel
BuildRequires:  java-ca-certificates
BuildRequires:  libX11-devel
BuildRequires:  libXi-devel
BuildRequires:  libXinerama-devel
BuildRequires:  libXt-devel
BuildRequires:  libXtst-devel
BuildRequires:  libjpeg-devel
BuildRequires:  liblcms2-devel
BuildRequires:  libpng-devel
BuildRequires:  libtool
BuildRequires:  libxslt
BuildRequires:  pkgconfig
BuildRequires:  unzip
BuildRequires:  update-desktop-files
BuildRequires:  xorg-x11-proto-devel
BuildRequires:  xprop
BuildRequires:  zip
BuildRequires:  pkgconfig(atk) >= 2.14.0
BuildRequires:  pkgconfig(atk-bridge-2.0)
BuildRequires:  pkgconfig(atspi-2) >= 2.14.0
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(gdk-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.32.0
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gthread-2.0)
# Requires rest of java
Requires:       %{name}-headless = %{version}-%{release}
Requires:       fontconfig
# mozilla-nss has to be installed to prevent
# java.security.ProviderException: Could not initialize NSS
# ...
# java.io.FileNotFoundException: /usr/lib64/libnss3.so
#was bnc#634793
Requires:       mozilla-nss
Requires(post): file
# Standard JPackage base provides.
Provides:       java = %{javaver}
Provides:       java-%{javaver} = %{version}-%{release}
Provides:       java-openjdk = %{version}-%{release}
Provides:       jre = %{javaver}
Provides:       jre-%{javaver} = %{version}-%{release}
Provides:       jre-%{javaver}-openjdk = %{version}-%{release}
Provides:       jre-openjdk = %{version}-%{release}
# Standard JPackage extensions provides.
Provides:       java-fonts = %{version}
# Required at least by fop
Provides:       java-%{bits} = %{javaver}
Provides:       java-%{javaver}-%{bits}
Provides:       java-openjdk-%{bits} = %{version}-%{release}
Provides:       jre-%{bits} = %{javaver}
Provides:       jre-%{javaver}-%{bits}
Provides:       jre-%{javaver}-openjdk-%{bits} = %{version}-%{release}
Provides:       jre-openjdk-%{bits} = %{version}-%{release}
Provides:       jre1.10.x
Provides:       jre1.3.x
Provides:       jre1.4.x
Provides:       jre1.5.x
Provides:       jre1.6.x
Provides:       jre1.7.x
Provides:       jre1.8.x
Provides:       jre1.9.x
%if %{bootcycle}
BuildRequires:  java-devel >= 9
BuildConflicts: java-devel >= 11
%else
BuildRequires:  %{name}-devel
%endif
# Zero-assembler build requirement.
%if %{with zero}
BuildRequires:  libffi-devel
%endif
%if %{with_systemtap}
BuildRequires:  systemtap-sdt-devel
%endif
# pulse audio requirements
%if %{with_pulseaudio}
BuildRequires:  libpulse-devel >= 0.9.11
BuildRequires:  pulseaudio >= 0.9.11
%endif
%if %{with_system_pcsc}
BuildRequires:  pcsc-lite-devel
%endif
%if %{with aot}
BuildRequires:  libelf-devel
%endif

%description
The OpenJDK 10 runtime environment.

%package headless
Summary:        OpenJDK 10 Runtime Environment
Group:          Development/Languages/Java
Requires:       jpackage-utils
# Post requires update-alternatives to install tool update-alternatives.
Requires(post): update-alternatives
Requires(post): java-ca-certificates
# Postun requires update-alternatives to uninstall tool update-alternatives.
Requires(postun): update-alternatives
Recommends:     tzdata-java8
# Standard JPackage base provides.
Provides:       java-%{javaver}-headless = %{version}-%{release}
Provides:       java-headless = %{javaver}
Provides:       java-openjdk-headless = %{version}-%{release}
Provides:       jre-%{javaver}-headless = %{version}-%{release}
Provides:       jre-%{javaver}-openjdk-headless = %{version}-%{release}
Provides:       jre-headless = %{javaver}
Provides:       jre-openjdk-headless = %{version}-%{release}
# Standard JPackage extensions provides.
Provides:       jaas = %{version}
Provides:       java-sasl = %{version}
Provides:       jce = %{version}
Provides:       jdbc-stdext = 4.3
Provides:       jndi = %{version}
Provides:       jndi-cos = %{version}
Provides:       jndi-dns = %{version}
Provides:       jndi-ldap = %{version}
Provides:       jndi-rmi = %{version}
Provides:       jsse = %{version}

%description headless
The OpenJDK 10 runtime environment without audio and video support.

%package devel
Summary:        OpenJDK 10 Development Environment
# Require base package.
Group:          Development/Languages/Java
Requires:       %{name} = %{version}-%{release}
# Post requires update-alternatives to install tool update-alternatives.
Requires(post): update-alternatives
# Postun requires update-alternatives to uninstall tool update-alternatives.
Requires(postun): update-alternatives
# Standard JPackage devel provides.
Provides:       java-%{javaver}-devel = %{version}
Provides:       java-devel = %{javaver}
Provides:       java-devel-openjdk = %{version}
Provides:       java-sdk = %{javaver}
Provides:       java-sdk-%{javaver} = %{version}
Provides:       java-sdk-%{javaver}-openjdk = %{version}
Provides:       java-sdk-openjdk = %{version}

%description devel
The OpenJDK 10 development tools.

%package jmods
Summary:        JMods for OpenJDK 10
Group:          Development/Languages/Java
Requires:       %{name}-devel = %{version}-%{release}

%description jmods
The JMods for OpenJDK 10.

%package demo
Summary:        OpenJDK 10 Demos
Group:          Development/Languages/Java
Requires:       %{name} = %{version}-%{release}

%description demo
The OpenJDK 10 demos.

%package src
Summary:        OpenJDK 10 Source Bundle
Group:          Development/Languages/Java
Requires:       %{name} = %{version}-%{release}

%description src
The OpenJDK 10 source bundle.

%package javadoc
Summary:        OpenJDK 10 API Documentation
Group:          Development/Languages/Java
Requires:       jpackage-utils
# Post requires update-alternatives to install javadoc alternative.
Requires(post): update-alternatives
# Postun requires update-alternatives to uninstall javadoc alternative.
Requires(postun): update-alternatives
# Standard JPackage javadoc provides.
Provides:       java-%{javaver}-javadoc = %{version}-%{release}
Provides:       java-javadoc = %{version}-%{release}
BuildArch:      noarch

%description javadoc
The OpenJDK 10 API documentation.

%package accessibility
Summary:        OpenJDK 10 accessibility connector
Group:          Development/Languages/Java
Requires:       %{name} = %{version}-%{release}
Requires:       xprop

%description accessibility
Enables accessibility support in OpenJDK 10 by using java-atk-wrapper. This allows
compatible at-spi2 based accessibility programs to work for AWT and Swing-based
programs.

Please note, the java-atk-wrapper is still in beta, and OpenJDK 10 itself is still
being tuned to be working with accessibility features. There are known issues
with accessibility on, so please do not install this package unless you really
need to.

%prep
%setup -q -n %{hg_repository}-%{hg_revision}
%setup -q -D -n %{hg_repository}-%{hg_revision} -T -a 8
%setup -q -D -n %{hg_repository}-%{hg_revision} -T -a 9

# Replace config.sub and config.guess with fresh versions
cp %{SOURCE100} make/autoconf/build-aux/
cp %{SOURCE101} make/autoconf/build-aux/

# Remove libraries that are linked
rm -rvf src/java.base/share/native/libzip/zlib-*
find src/java.desktop/share/native/libjavajpeg ! -name imageioJPEG.c ! -name jpegdecoder.c -type f -delete
rm -rvf src/java.desktop/share/native/libsplashscreen/libpng
rm -rvf src/java.desktop/share/native/libsplashscreen/giflib
rm -rvf src/java.desktop/share/native/liblcms/cms*
rm -rvf src/java.desktop/share/native/liblcms/lcms2*

%patch1
%if %{with_pulseaudio}
%patch2 -p1
%endif

%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch8 -p1
%patch10 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1

%if %{with_system_pcsc}
%patch15 -p1
%endif

# s390 build fixes

%ifarch s390
%patch100 -p1
%patch101 -p1
%endif

%patch102 -p1

%if 0%{?suse_version} >= 1330
%patch103 -p1
%endif

%patch200 -p1

%ifarch %{arm6}
%patch201 -p0
%endif

%patch300 -p1
%patch302 -p1
%patch303 -p1

%patch800 -p1

%patch400
%patch401

# Extract systemtap tapsets

%if %{with_systemtap}

tar -x -I xz -f %{SOURCE10}

for file in tapset/*.in; do

    OUTPUT_FILE=`echo $file | sed -e s:\.in$::g`
    sed -e s:@ABS_SERVER_LIBJVM_SO@:%{_jvmdir}/%{sdkdir}/lib/server/libjvm.so:g $file > $file.1
# TODO find out which architectures other than ix86 have a client vm

%ifarch %{ix86} %{arm6}
    sed -e s:@ABS_CLIENT_LIBJVM_SO@:%{_jvmdir}/%{sdkdir}/lib/client/libjvm.so:g $file.1 > $OUTPUT_FILE
%else
    sed -e '/@ABS_CLIENT_LIBJVM_SO@/d' $file.1 > $OUTPUT_FILE
%endif
    sed -i -e s:@ABS_JAVA_HOME_DIR@:%{_jvmdir}/%{sdkdir}:g $OUTPUT_FILE

done

%endif

# Prepare desktop files
for file in %{SOURCE11} %{SOURCE12} ; do
    OUTPUT_FILE=`basename $file | sed -e s:\.in$::g`
    sed -e s:@JAVA_HOME@:%{_jvmdir}/%{sdkdir}:g $file > $OUTPUT_FILE
    sed -i -e s:@VERSION@:%{javaver}.%{_arch}:g $OUTPUT_FILE
done

%build
# How many cpu's do we have?
export NUM_PROC=`%{_bindir}/getconf _NPROCESSORS_ONLN 2> /dev/null || :`
export NUM_PROC=${NUM_PROC:-1}

# Build OpenJDK.

%ifarch s390x sparc64 alpha ppc64 ppc64le %{aarch64}
export ARCH_DATA_MODEL=64
%endif

%ifarch alpha
export CFLAGS="$CFLAGS -mieee"
%endif

EXTRA_CFLAGS="-Wno-error -DIMPROVED_FONT_RENDERING"
EXTRA_CPP_FLAGS="-Wno-error -DIMPROVED_FONT_RENDERING"

%ifarch ppc64 ppc64le ppc
EXTRA_CFLAGS="$EXTRA_CFLAGS -fno-strict-aliasing"
%endif

%if 0%{?suse_version} >= 1330
EXTRA_CFLAGS="$EXTRA_CFLAGS -Wno-error -std=gnu++98 -fno-delete-null-pointer-checks -fno-lifetime-dse -fpermissive"
EXTRA_CPP_FLAGS="$EXTRA_CPP_FLAGS -Wno-error -std=gnu++98 -fno-delete-null-pointer-checks -fno-lifetime-dse"
%endif

(cd make/autoconf
 bash ./autogen.sh
)

mkdir -p %{buildoutputdir}

pushd %{buildoutputdir}

bash ../configure \
    --with-version-feature=%{featurever} \
    --with-version-interim=%{interimver} \
    --with-version-update=%{updatever} \
    --with-version-patch=%{patchver} \
    --with-version-date=%{datever} \
    --with-version-build=%{buildver} \
    --with-version-pre="" \
    --with-version-opt="suse-%{release}-%{_arch}" \
    --disable-warnings-as-errors \
%if %{with zero}
    --with-jvm-variants=zero \
%else
%ifarch %{arm6}
    --with-jvm-variants=client \
%endif
%endif
%if %{with aot}
    --enable-aot \
%else
    --disable-aot \
%endif
    --disable-zip-debug-info \
    --disable-keep-packaged-modules \
    --with-debug-level=%{debugbuild} \
    --with-zlib=system \
    --with-libjpeg=system \
    --with-giflib=system \
    --with-libpng=system \
    --with-lcms=system \
%if %{with_system_pcsc}
    --with-pcsclite=system \
%endif
    --with-stdc++lib=dynamic \
%ifnarch %{arm}
    --with-num-cores="$NUM_PROC" \
%endif
%ifarch s390
    --with-boot-jdk-jvmargs="-Xms256M -Xmx768M" \
%endif
    --with-extra-cxxflags="$EXTRA_CPP_FLAGS" \
    --with-extra-cflags="$EXTRA_CFLAGS" \
    --disable-javac-server

# The combination of FULL_DEBUG_SYMBOLS=0 and ALT_OBJCOPY=/does_not_exist
# disables FDS for all build configs and reverts to pre-FDS make %{?_smp_mflags} logic.
# STRIP_POLICY=none says don't do any stripping. DEBUG_BINARIES=true says
# ignore all the other logic about which debug options and just do '-g'.

make \
    JAVAC_FLAGS=-g \
    LOG=trace \
    DEBUG_BINARIES=true \
    STRIP_POLICY=no_strip \
    POST_STRIP_CMD="" \
    WARNINGS_ARE_ERRORS="-Wno-error" \
    CFLAGS_WARNINGS_ARE_ERRORS="-Wno-error" \
    %{imagestarget} docs

# remove redundant *diz and *debuginfo files
find %{imagesdir}/jdk -iname '*.diz' -exec rm {} \;
find %{imagesdir}/jdk -iname '*.debuginfo' -exec rm {} \;

popd >& /dev/null

export JAVA_HOME=$(pwd)/%{buildoutputdir}/%{imagesdir}/jdk

# Copy tz.properties
echo "sun.zoneinfo.dir=%{_datadir}/javazi" >> $JAVA_HOME/conf/tz.properties

%if %{with_pulseaudio}
# Build the pulseaudio plugin
pushd icedtea-sound-%{icedtea_sound_version}
autoreconf --force --install
%configure \
    --with-jdk-home=$JAVA_HOME \
    --disable-docs
make %{?_smp_mflags}
cp icedtea-sound.jar $JAVA_HOME/../jmods/
cp build/native/libicedtea-sound.so $JAVA_HOME/lib/
popd
# Merge the icedtea-sound into the JDK
source $JAVA_HOME/release; export MODULES
$JAVA_HOME/bin/jlink --module-path $JAVA_HOME/../jmods --add-modules "icedtea.sound,${MODULES//\ /,}" --output $JAVA_HOME/../newjdk
cp -rf $JAVA_HOME/../newjdk/* $JAVA_HOME/
rm -rf $JAVA_HOME/../newjdk
%endif

# Build the accessibility plugin
pushd java-atk-wrapper-%{java_atk_wrapper_version}
autoreconf --force --install
rm wrapper/org/GNOME/Accessibility/AtkWrapper.java
%configure \
    --without-jdk-auto-detect \
    JDK_SRC=$JAVA_HOME
rm wrapper/org/GNOME/Accessibility/AtkWrapper.java
make %{?_smp_mflags}
cp wrapper/java-atk-wrapper.jar $JAVA_HOME/../jmods/
cp jni/src/.libs/libatk-wrapper.so $JAVA_HOME/lib/
popd
# Merge the java-atk-wrapper into the JDK
source $JAVA_HOME/release; export MODULES
$JAVA_HOME/bin/jlink --module-path $JAVA_HOME/../jmods --add-modules "atk.wrapper,${MODULES//\ /,}" --output $JAVA_HOME/../newjdk
cp -rf $JAVA_HOME/../newjdk/* $JAVA_HOME/
rm -rf $JAVA_HOME/../newjdk

# cacerts are generated in runtime in openSUSE
if [ -f %{buildoutputdir}/%{imagesdir}/jdk/lib/security/cacerts ]; then
        rm %{buildoutputdir}/%{imagesdir}/jdk/lib/security/cacerts
fi

# Check debug symbols are present and can identify code
SERVER_JVM="$JAVA_HOME/lib/server/libjvm.so"
if [ -f "$SERVER_JVM" ] ; then
  nm -aCl "$SERVER_JVM" | grep javaCalls.cpp
fi
CLIENT_JVM="$JAVA_HOME/lib/client/libjvm.so"
if [ -f "$CLIENT_JVM" ] ; then
  nm -aCl "$CLIENT_JVM" | grep javaCalls.cpp
fi
ZERO_JVM="$JAVA_HOME/lib/zero/libjvm.so"
if [ -f "$ZERO_JVM" ] ; then
  nm -aCl "$ZERO_JVM" | grep javaCalls.cpp
fi

# Check unlimited policy has been used
$JAVA_HOME/bin/javac -d . %{SOURCE14}
$JAVA_HOME/bin/java --add-opens java.base/javax.crypto=ALL-UNNAMED TestCryptoLevel

# Check ECC is working
$JAVA_HOME/bin/javac -d . %{SOURCE15}
#FIXME make it run after system NSS support?
$JAVA_HOME/bin/java $(echo $(basename %{SOURCE15})|sed "s|\.java||") || true

%install
export LANG=en_US.UTF-8
#bnc#530046
export STRIP_KEEP_SYMTAB=libjvm*
# skip /usr/lib/rpm/brp-check-bytecode-version:
export NO_BRP_CHECK_BYTECODE_VERSION=true

%if %{with_systemtap}
  # Install systemtap support files.
  install -dm 755 %{buildroot}%{_jvmdir}/%{sdkdir}/tapset
  cp -a tapset/*.stp %{buildroot}%{_jvmdir}/%{sdkdir}/tapset/
  install -d -m 755 %{buildroot}%{tapsetdir}
  pushd %{buildroot}%{tapsetdir}
    RELATIVE=$(%{abs2rel} %{_jvmdir}/%{sdkdir}/tapset %{tapsetdir})
    ln -sf $RELATIVE/*.stp .
  popd
%endif

pushd %{buildoutputdir}/%{imagesdir}/jdk

  # Install main files.
  install -d -m 755 %{buildroot}%{_jvmdir}/%{sdkdir}
  cp -a bin include lib conf release %{buildroot}%{_jvmdir}/%{sdkdir}

  # Install JCE policy symlinks.
  install -d -m 755 %{buildroot}%{_jvmprivdir}/%{archname}/jce/vanilla

  # Install versionless symlinks.
  pushd %{buildroot}%{_jvmdir}
    ln -sf %{sdkdir} %{jrelnk}
    ln -sf %{sdkdir} %{sdklnk}
  popd

  # Remove javaws man page
  rm -f man/man1/javaws*

  # Install man pages.
  install -d -m 755 %{buildroot}%{_mandir}/man1
  for manpage in man/man1/*
  do
    # Convert man pages to UTF8 encoding.
    iconv -f ISO_8859-1 -t UTF8 $manpage -o $manpage.tmp
    mv -f $manpage.tmp $manpage
    install -m 644 -p $manpage %{buildroot}%{_mandir}/man1/$(basename \
      $manpage .1)-%{sdklnk}.1
  done

  # Install demos and samples.
  cp -a demo %{buildroot}%{_jvmdir}/%{sdkdir}
  # enable short-circuit
  mkdir -p sample/rmi
  [ -f bin/java-rmi.cgi ] && mv bin/java-rmi.cgi sample/rmi
  cp -a sample %{buildroot}%{_jvmdir}/%{sdkdir}

popd

pushd %{buildoutputdir}/%{imagesdir}

  # Install jmods
  cp -a jmods %{buildroot}%{_jvmdir}/%{sdkdir}

popd

# Install nss.cfg
install -m 644 %{SOURCE13} %{buildroot}%{_jvmdir}/%{sdkdir}/lib/security/

# Install Javadoc documentation.
install -d -m 755 %{buildroot}%{_javadocdir}
cp -a %{buildoutputdir}/images/docs %{buildroot}%{_javadocdir}/%{sdklnk}

# Install icons and menu entries.
for s in 16 24 32 48 ; do
  install -D -p -m 644 \
    src/java.desktop/unix/classes/sun/awt/X11/java-icon${s}.png \
    %{buildroot}%{_datadir}/icons/hicolor/${s}x${s}/apps/java-%{javaver}.png
done

# Install desktop file.
install -d -m 0755 %{buildroot}%{_datadir}/{applications,pixmaps}
install -d -m 0755 %{buildroot}/%{_jvmdir}/%{sdkdir}/lib/desktop/
install -m 0644 jconsole.desktop %{buildroot}/%{_jvmdir}/%{sdkdir}/lib/desktop/
%suse_update_desktop_file %{buildroot}/%{_jvmdir}/%{sdkdir}/lib/desktop/jconsole.desktop

# Find demo directories.
find %{buildroot}%{_jvmdir}/%{sdkdir}/demo \
  %{buildroot}%{_jvmdir}/%{sdkdir}/sample -type d \
  | sed 's|'%{buildroot}'|%dir |' \
  > %{name}-demo.files

# FIXME: remove SONAME entries from demo DSOs.  See
# https://bugzilla.redhat.com/show_bug.cgi?id=436497

# Find non-documentation demo files.
find %{buildroot}%{_jvmdir}/%{sdkdir}/demo \
  %{buildroot}%{_jvmdir}/%{sdkdir}/sample \
  -type f -o -type l | sort \
  | grep -v README \
  | sed 's|'%{buildroot}'||' \
  >> %{name}-demo.files
# Find documentation demo files.
find %{buildroot}%{_jvmdir}/%{sdkdir}/demo \
  %{buildroot}%{_jvmdir}/%{sdkdir}/sample \
  -type f -o -type l | sort \
  | grep README \
  | sed 's|'%{buildroot}'||' \
  | sed 's|^|%doc |' \
  >> %{name}-demo.files

# Create a config file to  enable java-atk-wrapper
pushd %{buildroot}/%{_jvmdir}/%{sdkdir}/conf/
  echo "#Config file to  enable java-atk-wrapper" > accessibility.properties
  echo "" >> accessibility.properties
  echo "assistive_technologies=org.GNOME.Accessibility.AtkWrapper" >> accessibility.properties
  echo "" >> accessibility.properties
popd

# fdupes links the files from JDK to JRE, so it breaks a JRE
# use it carefully :))
%fdupes -s %{buildroot}/%{_jvmdir}/%{sdkdir}/
%fdupes -s %{buildroot}/%{_jvmdir}/%{sdkdir}/demo
%fdupes -s %{buildroot}%{_javadocdir}/%{sdklnk}

%post headless
ext=.gz
# At a certain point, idlj and idlj was slave of java instead of
# javac. This allows the upgrade pass without errors.
if update-alternatives --query java | grep idlj >/dev/null 2>&1
then
  update-alternatives --remove java %{jrebindir}/java
fi
update-alternatives \
  --install %{_bindir}/java java %{jrebindir}/java %{priority} \
  --slave %{_jvmdir}/jre jre %{_jvmdir}/%{jrelnk} \
  --slave %{_bindir}/jjs jjs %{jrebindir}/jjs \
  --slave %{_bindir}/keytool keytool %{jrebindir}/keytool \
  --slave %{_bindir}/orbd orbd %{jrebindir}/orbd \
  --slave %{_bindir}/rmid rmid %{jrebindir}/rmid \
  --slave %{_bindir}/rmiregistry rmiregistry %{jrebindir}/rmiregistry \
  --slave %{_bindir}/servertool servertool %{jrebindir}/servertool \
  --slave %{_bindir}/tnameserv tnameserv %{jrebindir}/tnameserv \
  --slave %{_mandir}/man1/java.1$ext java.1$ext \
  %{_mandir}/man1/java-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jjs.1$ext jjs.1$ext \
  %{_mandir}/man1/jjs-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/keytool.1$ext keytool.1$ext \
  %{_mandir}/man1/keytool-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/orbd.1$ext orbd.1$ext \
  %{_mandir}/man1/orbd-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/rmid.1$ext rmid.1$ext \
  %{_mandir}/man1/rmid-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/rmiregistry.1$ext rmiregistry.1$ext \
  %{_mandir}/man1/rmiregistry-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/servertool.1$ext servertool.1$ext \
  %{_mandir}/man1/servertool-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/tnameserv.1$ext tnameserv.1$ext \
  %{_mandir}/man1/tnameserv-%{sdklnk}.1$ext

update-alternatives \
  --install %{_jvmdir}/jre-openjdk \
  jre_openjdk %{_jvmdir}/%{jrelnk} %{priority}
update-alternatives \
  --install %{_jvmdir}/jre-%{javaver} \
  jre_%{javaver} %{_jvmdir}/%{jrelnk} %{priority}

%postun headless
if [ $1 -eq 0 ]
then
  if test -f /proc/sys/fs/binfmt_misc/jarexec
  then
    echo '-1' > /proc/sys/fs/binfmt_misc/jarexec
  fi
  update-alternatives --remove java %{jrebindir}/java
  update-alternatives --remove jre_openjdk %{_jvmdir}/%{jrelnk}
  update-alternatives --remove jre_%{javaver} %{_jvmdir}/%{jrelnk}
fi

%posttrans headless
# bnc#781690#c11: don't trust user defined JAVA_HOME and use the current VM
# XXX: this might conflict between various versions of openjdk
export JAVA_HOME=%{_jvmdir}/%{jrelnk}

# check if the java-cacerts is a valid keystore (bnc#781690)
if [ X"`%{_bindir}/file --mime-type -b %{javacacerts}`" \
    != "Xapplication/x-java-keystore;" ]; then
%if 0%{?suse_version} <= 1310
    # workaround for bnc#847952 - pre 13.1 keyring.jar attempts to load invalid keystore and fail on it
    rm -f "%{javacacerts}"
%endif
    %{_sbindir}/update-ca-certificates
fi

# remove the default empty cacert file, if it's installed
if [ 0`stat -c "%{s}" %{cacerts} 2>/dev/null` = "032" ] ; then
    rm -f %{cacerts}
fi

# if cacerts does exists, neither does not contain/point to a
# valid keystore (bnc#781690) ...
if [ X"`%{_bindir}/file --mime-type -b -L %{cacerts}`" \
    != "Xapplication/x-java-keystore;" ]; then
    # bnc#727223
    rm -f %{cacerts}
    ln -s %{javacacerts} %{cacerts}
fi

%post devel
ext=.gz
update-alternatives \
  --install %{_bindir}/javac javac %{sdkbindir}/javac %{priority} \
  --slave %{_jvmdir}/java java_sdk %{_jvmdir}/%{sdklnk} \
  --slave %{_bindir}/appletviewer appletviewer %{sdkbindir}/appletviewer \
  --slave %{_bindir}/idlj idlj %{jrebindir}/idlj \
%if %{with aot}
  --slave %{_bindir}/jaotc jaotc %{sdkbindir}/jaotc \
%endif
  --slave %{_bindir}/jar jar %{sdkbindir}/jar \
  --slave %{_bindir}/jarsigner jarsigner %{sdkbindir}/jarsigner \
  --slave %{_bindir}/javadoc javadoc %{sdkbindir}/javadoc \
  --slave %{_bindir}/javap javap %{sdkbindir}/javap \
  --slave %{_bindir}/jcmd jcmd %{sdkbindir}/jcmd \
  --slave %{_bindir}/jconsole jconsole %{sdkbindir}/jconsole \
  --slave %{_bindir}/jdb jdb %{sdkbindir}/jdb \
  --slave %{_bindir}/jdeprscan jdeprscan %{sdkbindir}/jdeprscan \
  --slave %{_bindir}/jdeps jdeps %{sdkbindir}/jdeps \
%if ! %{with zero}
  --slave %{_bindir}/jhsdb jhsdb %{sdkbindir}/jhsdb \
%endif
  --slave %{_bindir}/jimage jimage %{sdkbindir}/jimage \
  --slave %{_bindir}/jinfo jinfo %{sdkbindir}/jinfo \
  --slave %{_bindir}/jlink jlink %{sdkbindir}/jlink \
  --slave %{_bindir}/jmap jmap %{sdkbindir}/jmap \
  --slave %{_bindir}/jmod jmod %{sdkbindir}/jmod \
  --slave %{_bindir}/jps jps %{sdkbindir}/jps \
  --slave %{_bindir}/jrunscript jrunscript %{sdkbindir}/jrunscript \
  --slave %{_bindir}/jshell jshell %{sdkbindir}/jshell \
  --slave %{_bindir}/jstack jstack %{sdkbindir}/jstack \
  --slave %{_bindir}/jstat jstat %{sdkbindir}/jstat \
  --slave %{_bindir}/jstatd jstatd %{sdkbindir}/jstatd \
  --slave %{_bindir}/pack200 pack200 %{sdkbindir}/pack200 \
  --slave %{_bindir}/rmic rmic %{sdkbindir}/rmic \
  --slave %{_bindir}/schemagen schemagen %{sdkbindir}/schemagen \
  --slave %{_bindir}/serialver serialver %{sdkbindir}/serialver \
  --slave %{_bindir}/unpack200 unpack200 %{sdkbindir}/unpack200 \
  --slave %{_bindir}/wsgen wsgen %{sdkbindir}/wsgen \
  --slave %{_bindir}/wsimport wsimport %{sdkbindir}/wsimport \
  --slave %{_bindir}/xjc xjc %{sdkbindir}/xjc \
  --slave %{_mandir}/man1/appletviewer.1$ext appletviewer.1$ext \
  %{_mandir}/man1/appletviewer-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/idlj.1$ext idlj.1$ext \
  %{_mandir}/man1/idlj-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jar.1$ext jar.1$ext \
  %{_mandir}/man1/jar-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jarsigner.1$ext jarsigner.1$ext \
  %{_mandir}/man1/jarsigner-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/javac.1$ext javac.1$ext \
  %{_mandir}/man1/javac-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/javadoc.1$ext javadoc.1$ext \
  %{_mandir}/man1/javadoc-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/javap.1$ext javap.1$ext \
  %{_mandir}/man1/javap-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jcmd.1$ext jcmd.1$ext \
  %{_mandir}/man1/jcmd-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jconsole.1$ext jconsole.1$ext \
  %{_mandir}/man1/jconsole-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jdb.1$ext jdb.1$ext \
  %{_mandir}/man1/jdb-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jdeps.1$ext jdeps.1$ext \
  %{_mandir}/man1/jdeps-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jinfo.1$ext jinfo.1$ext \
  %{_mandir}/man1/jinfo-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jmap.1$ext jmap.1$ext \
  %{_mandir}/man1/jmap-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jps.1$ext jps.1$ext \
  %{_mandir}/man1/jps-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jrunscript.1$ext jrunscript.1$ext \
  %{_mandir}/man1/jrunscript-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jstack.1$ext jstack.1$ext \
  %{_mandir}/man1/jstack-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jstat.1$ext jstat.1$ext \
  %{_mandir}/man1/jstat-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jstatd.1$ext jstatd.1$ext \
  %{_mandir}/man1/jstatd-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/pack200.1$ext pack200.1$ext \
  %{_mandir}/man1/pack200-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/rmic.1$ext rmic.1$ext \
  %{_mandir}/man1/rmic-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/schemagen.1$ext schemagen.1$ext \
  %{_mandir}/man1/schemagen-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/serialver.1$ext serialver.1$ext \
  %{_mandir}/man1/serialver-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/unpack200.1$ext unpack200.1$ext \
  %{_mandir}/man1/unpack200-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/wsgen.1$ext wsgen.1$ext \
  %{_mandir}/man1/wsgen-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/wsimport.1$ext wsimport.1$ext \
  %{_mandir}/man1/wsimport-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/xjc.1$ext xjc.1$ext \
  %{_mandir}/man1/xjc-%{sdklnk}.1$ext \
  --slave %{_datadir}/applications/jconsole.desktop jconsole.desktop \
  %{_jvmdir}/%{sdkdir}/lib/desktop/jconsole.desktop

update-alternatives \
  --install %{_jvmdir}/java-openjdk \
  java_sdk_openjdk %{_jvmdir}/%{sdklnk} %{priority}
update-alternatives \
  --install %{_jvmdir}/java-%{javaver} \
  java_sdk_%{javaver} %{_jvmdir}/%{sdklnk} %{priority}

%postun devel
if [ $1 -eq 0 ]
then
  update-alternatives --remove javac %{sdkbindir}/javac
  update-alternatives --remove java_sdk_openjdk %{_jvmdir}/%{sdklnk}
  update-alternatives --remove java_sdk_%{javaver} %{_jvmdir}/%{sdklnk}
fi

%post javadoc
update-alternatives \
  --install %{_javadocdir}/java javadocdir %{_javadocdir}/%{sdklnk}/api \
  %{priority}

%postun javadoc
if [ $1 -eq 0 ]
then
  update-alternatives --remove javadocdir %{_javadocdir}/%{sdklnk}/api
fi

%files
%dir %{_jvmdir}/%{sdkdir}/lib
%{_jvmdir}/%{sdkdir}/lib/libawt_xawt.so
%if %{with_pulseaudio}
%{_jvmdir}/%{sdkdir}/lib/libicedtea-sound.so
%endif
%{_jvmdir}/%{sdkdir}/lib/libjawt.so
%{_jvmdir}/%{sdkdir}/lib/libjsoundalsa.so
%{_jvmdir}/%{sdkdir}/lib/libsplashscreen.so
%dir %{_datadir}/icons/hicolor
%{_datadir}/icons/hicolor/*x*/apps/java-%{javaver}.png

%files headless
%dir %{_jvmdir}
%dir %{_jvmdir}/%{sdkdir}/
%dir %{_jvmdir}/%{sdkdir}/bin
%dir %{_jvmdir}/%{sdkdir}/lib
%dir %{_jvmdir}/%{sdkdir}/lib/jli
%ifarch %{arm6}
%dir %{_jvmdir}/%{sdkdir}/lib/client
%else
%dir %{_jvmdir}/%{sdkdir}/lib/server
%endif
%dir %{_jvmdir}/%{sdkdir}/lib/desktop
%dir %{_jvmdir}/%{sdkdir}/lib/security

%dir %{_jvmdir}/%{sdkdir}/conf
%dir %{_jvmdir}/%{sdkdir}/conf/security
%dir %{_jvmdir}/%{sdkdir}/conf/security/policy
%dir %{_jvmdir}/%{sdkdir}/conf/security/policy/unlimited
%dir %{_jvmdir}/%{sdkdir}/conf/security/policy/limited
%dir %{_jvmdir}/%{sdkdir}/conf/management

%dir %{_jvmdir}/%{sdkdir}
%{_jvmdir}/%{jrelnk}
%{_jvmprivdir}/*

%{_jvmdir}/%{sdkdir}/bin/java
%{_jvmdir}/%{sdkdir}/bin/jjs
%{_jvmdir}/%{sdkdir}/bin/keytool
%{_jvmdir}/%{sdkdir}/bin/orbd
%{_jvmdir}/%{sdkdir}/bin/rmid
%{_jvmdir}/%{sdkdir}/bin/rmiregistry
%{_jvmdir}/%{sdkdir}/bin/servertool
%{_jvmdir}/%{sdkdir}/bin/tnameserv
%{_jvmdir}/%{sdkdir}/conf/logging.properties
%{_jvmdir}/%{sdkdir}/conf/management/jmxremote.access
%{_jvmdir}/%{sdkdir}/conf/management/jmxremote.password.template
%{_jvmdir}/%{sdkdir}/conf/management/management.properties
%{_jvmdir}/%{sdkdir}/conf/net.properties
%{_jvmdir}/%{sdkdir}/conf/security/java.policy
%{_jvmdir}/%{sdkdir}/conf/security/java.security
%{_jvmdir}/%{sdkdir}/conf/security/policy/limited/default_local.policy
%{_jvmdir}/%{sdkdir}/conf/security/policy/limited/default_US_export.policy
%{_jvmdir}/%{sdkdir}/conf/security/policy/limited/exempt_local.policy
%{_jvmdir}/%{sdkdir}/conf/security/policy/README.txt
%{_jvmdir}/%{sdkdir}/conf/security/policy/unlimited/default_local.policy
%{_jvmdir}/%{sdkdir}/conf/security/policy/unlimited/default_US_export.policy
%{_jvmdir}/%{sdkdir}/conf/sound.properties
%{_jvmdir}/%{sdkdir}/conf/tz.properties
%if ! %{with zero}
%{_jvmdir}/%{sdkdir}/lib/classlist
%endif
%{_jvmdir}/%{sdkdir}/lib/desktop/jconsole.desktop
%{_jvmdir}/%{sdkdir}/lib/jexec
%{_jvmdir}/%{sdkdir}/lib/jli/libjli.so
%{_jvmdir}/%{sdkdir}/lib/jrt-fs.jar
%{_jvmdir}/%{sdkdir}/lib/jvm.cfg
%{_jvmdir}/%{sdkdir}/lib/libawt_headless.so
%{_jvmdir}/%{sdkdir}/lib/libawt.so
%{_jvmdir}/%{sdkdir}/lib/libdt_socket.so
%{_jvmdir}/%{sdkdir}/lib/libextnet.so
%{_jvmdir}/%{sdkdir}/lib/libfontmanager.so
%{_jvmdir}/%{sdkdir}/lib/libinstrument.so
%{_jvmdir}/%{sdkdir}/lib/libj2gss.so
%{_jvmdir}/%{sdkdir}/lib/libj2pcsc.so
%{_jvmdir}/%{sdkdir}/lib/libj2pkcs11.so
%{_jvmdir}/%{sdkdir}/lib/libjaas_unix.so
%{_jvmdir}/%{sdkdir}/lib/libjavajpeg.so
%{_jvmdir}/%{sdkdir}/lib/libjava.so
%{_jvmdir}/%{sdkdir}/lib/libjdwp.so
%{_jvmdir}/%{sdkdir}/lib/libjimage.so
%{_jvmdir}/%{sdkdir}/lib/libjsig.so
%{_jvmdir}/%{sdkdir}/lib/libjsound.so
%{_jvmdir}/%{sdkdir}/lib/liblcms.so
%{_jvmdir}/%{sdkdir}/lib/libmanagement_agent.so
%{_jvmdir}/%{sdkdir}/lib/libmanagement_ext.so
%{_jvmdir}/%{sdkdir}/lib/libmanagement.so
%{_jvmdir}/%{sdkdir}/lib/libmlib_image.so
%{_jvmdir}/%{sdkdir}/lib/libnet.so
%{_jvmdir}/%{sdkdir}/lib/libnio.so
%{_jvmdir}/%{sdkdir}/lib/libprefs.so
%{_jvmdir}/%{sdkdir}/lib/librmi.so
%{_jvmdir}/%{sdkdir}/lib/libsctp.so
%{_jvmdir}/%{sdkdir}/lib/libsunec.so
%{_jvmdir}/%{sdkdir}/lib/libunpack.so
%{_jvmdir}/%{sdkdir}/lib/libverify.so
%{_jvmdir}/%{sdkdir}/lib/libzip.so
%{_jvmdir}/%{sdkdir}/lib/modules
%{_jvmdir}/%{sdkdir}/lib/psfontj2d.properties
%{_jvmdir}/%{sdkdir}/lib/psfont.properties.ja
%{_jvmdir}/%{sdkdir}/lib/tzdb.dat
%{_jvmdir}/%{sdkdir}/lib/*/libjsig.so
%{_jvmdir}/%{sdkdir}/lib/*/libjvm.so
%{_jvmdir}/%{sdkdir}/lib/*/Xusage.txt

%config(noreplace) %{_jvmdir}/%{sdkdir}/lib/security/blacklisted.certs
%config(noreplace) %{_jvmdir}/%{sdkdir}/lib/security/nss.cfg
%{_jvmdir}/%{sdkdir}/lib/security/default.policy

%{_mandir}/man1/java-%{sdklnk}.1*
%{_mandir}/man1/jjs-%{sdklnk}.1*
%{_mandir}/man1/keytool-%{sdklnk}.1*
%{_mandir}/man1/orbd-%{sdklnk}.1*
%{_mandir}/man1/rmid-%{sdklnk}.1*
%{_mandir}/man1/rmiregistry-%{sdklnk}.1*
%{_mandir}/man1/servertool-%{sdklnk}.1*
%{_mandir}/man1/tnameserv-%{sdklnk}.1*

%files devel
%dir %{_jvmdir}/%{sdkdir}/bin
%dir %{_jvmdir}/%{sdkdir}/include
%dir %{_jvmdir}/%{sdkdir}/include/linux
%dir %{_jvmdir}/%{sdkdir}/lib

%if %{with_systemtap}
%dir %{_jvmdir}/%{sdkdir}/tapset
%endif
%{_jvmdir}/%{sdkdir}/bin/appletviewer
%{_jvmdir}/%{sdkdir}/bin/idlj
%if %{with aot}
%{_jvmdir}/%{sdkdir}/bin/jaotc
%endif
%{_jvmdir}/%{sdkdir}/bin/jar
%{_jvmdir}/%{sdkdir}/bin/jarsigner
%{_jvmdir}/%{sdkdir}/bin/javac
%{_jvmdir}/%{sdkdir}/bin/javadoc
%{_jvmdir}/%{sdkdir}/bin/javap
%{_jvmdir}/%{sdkdir}/bin/jcmd
%{_jvmdir}/%{sdkdir}/bin/jconsole
%{_jvmdir}/%{sdkdir}/bin/jdb
%{_jvmdir}/%{sdkdir}/bin/jdeprscan
%{_jvmdir}/%{sdkdir}/bin/jdeps
%if ! %{with zero}
%{_jvmdir}/%{sdkdir}/bin/jhsdb
%endif
%{_jvmdir}/%{sdkdir}/bin/jimage
%{_jvmdir}/%{sdkdir}/bin/jinfo
%{_jvmdir}/%{sdkdir}/bin/jlink
%{_jvmdir}/%{sdkdir}/bin/jmap
%{_jvmdir}/%{sdkdir}/bin/jmod
%{_jvmdir}/%{sdkdir}/bin/jps
%{_jvmdir}/%{sdkdir}/bin/jrunscript
%{_jvmdir}/%{sdkdir}/bin/jshell
%{_jvmdir}/%{sdkdir}/bin/jstack
%{_jvmdir}/%{sdkdir}/bin/jstat
%{_jvmdir}/%{sdkdir}/bin/jstatd
%{_jvmdir}/%{sdkdir}/bin/pack200
%{_jvmdir}/%{sdkdir}/bin/rmic
%{_jvmdir}/%{sdkdir}/bin/schemagen
%{_jvmdir}/%{sdkdir}/bin/serialver
%{_jvmdir}/%{sdkdir}/bin/unpack200
%{_jvmdir}/%{sdkdir}/bin/wsgen
%{_jvmdir}/%{sdkdir}/bin/wsimport
%{_jvmdir}/%{sdkdir}/bin/xjc
%{_jvmdir}/%{sdkdir}/include/classfile_constants.h
%{_jvmdir}/%{sdkdir}/include/ir.idl
%{_jvmdir}/%{sdkdir}/include/jawt.h
%{_jvmdir}/%{sdkdir}/include/jdwpTransport.h
%{_jvmdir}/%{sdkdir}/include/jni.h
%{_jvmdir}/%{sdkdir}/include/jvmticmlr.h
%{_jvmdir}/%{sdkdir}/include/jvmti.h
%{_jvmdir}/%{sdkdir}/include/linux/jawt_md.h
%{_jvmdir}/%{sdkdir}/include/linux/jni_md.h
%{_jvmdir}/%{sdkdir}/include/orb.idl
%{_jvmdir}/%{sdkdir}/lib/ct.sym
%{_jvmdir}/%{sdkdir}/lib/libattach.so
%if ! %{with zero}
%{_jvmdir}/%{sdkdir}/lib/libsaproc.so
%endif

%if %{with_systemtap}
%{_jvmdir}/%{sdkdir}/tapset/*.stp
%endif
%{_jvmdir}/%{sdklnk}
%{_mandir}/man1/appletviewer-%{sdklnk}.1*
%{_mandir}/man1/idlj-%{sdklnk}.1*
%{_mandir}/man1/jar-%{sdklnk}.1*
%{_mandir}/man1/jarsigner-%{sdklnk}.1*
%{_mandir}/man1/javac-%{sdklnk}.1*
%{_mandir}/man1/javadoc-%{sdklnk}.1*
%{_mandir}/man1/javap-%{sdklnk}.1*
%{_mandir}/man1/jcmd-%{sdklnk}.1*
%{_mandir}/man1/jconsole-%{sdklnk}.1*
%{_mandir}/man1/jdb-%{sdklnk}.1*
%{_mandir}/man1/jdeps-%{sdklnk}.1*
%{_mandir}/man1/jinfo-%{sdklnk}.1*
%{_mandir}/man1/jmap-%{sdklnk}.1*
%{_mandir}/man1/jps-%{sdklnk}.1*
%{_mandir}/man1/jrunscript-%{sdklnk}.1*
%{_mandir}/man1/jstack-%{sdklnk}.1*
%{_mandir}/man1/jstat-%{sdklnk}.1*
%{_mandir}/man1/jstatd-%{sdklnk}.1*
%{_mandir}/man1/pack200-%{sdklnk}.1*
%{_mandir}/man1/rmic-%{sdklnk}.1*
%{_mandir}/man1/schemagen-%{sdklnk}.1*
%{_mandir}/man1/serialver-%{sdklnk}.1*
%{_mandir}/man1/unpack200-%{sdklnk}.1*
%{_mandir}/man1/wsgen-%{sdklnk}.1*
%{_mandir}/man1/wsimport-%{sdklnk}.1*
%{_mandir}/man1/xjc-%{sdklnk}.1*

%if %{with_systemtap}
%{tapsetroot}
%endif

%files jmods
%dir %{_jvmdir}/%{sdkdir}/jmods
%{_jvmdir}/%{sdkdir}/release
%{_jvmdir}/%{sdkdir}/jmods/*.jmod
%if %{with_pulseaudio}
%{_jvmdir}/%{sdkdir}/jmods/icedtea-sound.jar
%endif
%{_jvmdir}/%{sdkdir}/jmods/java-atk-wrapper.jar

%files demo -f %{name}-demo.files

%files src
%{_jvmdir}/%{sdkdir}/lib/src.zip

%files javadoc
%dir %{_javadocdir}
%dir %{_javadocdir}/%{sdklnk}
%{_javadocdir}/%{sdklnk}/*

%files accessibility
%config(noreplace) %{_jvmdir}/%{sdkdir}/conf/accessibility.properties
%{_jvmdir}/%{sdkdir}/lib/libatk-wrapper.so

%changelog
* Tue Apr 23 2019 Fridrich Strba <fstrba@suse.com>
- Require update-ca-certificates by the headless subpackage
  (bsc#1131378)
* Wed Jul 18 2018 fstrba@suse.com
- OpenJDK 10.0.2 (July 2018 CPU)
  * Security fixes:
    + S8197925: Better stack walking (CVE-2018-2940, bsc#1101645)
    + S8199547: Exception to Pattern Syntax (CVE-2018-2952,
    bsc#1101651)
    + S8200332: Improve GCM counting (CVE-2018-2972, bsc#1101655)
    + S8200666: Improve LDAP support (CVE-2018-2973, bsc#1101656)
  * Security-In-Depth fixes:
    + S8191239: Improve desktop file usage
    + S8193419: Better Internet address support
  * Fixes
    + S8187577: JVM crash during gc doing concurrent marking
    + S8193802: NullPointerException from
    JarFileSystem.getVersionMap()
    + S8194554: filterArguments runs multiple filters in the wrong
    order
    + S8195096: Exception printed on console with custom LogManager
    on starting Apache Tomcat
    + S8196224: Even better Internet address support
    + S8199910: Compiler crashes with -g option and variables of
    intersection type inferred by `var`
    + S8200118: [TESTBUG] String concat tests should test
    toString() application order
    + S8200355: local variable inference regression test generates
    classfile in test folder
    + S8200359: (tz) Upgrade time-zone data to tzdata2018d
    + S8200556: AArch64: assertion failure in slowdebug builds
    + S8200640: Change version number to 10.0.2
    + S8200641: Update milestone to ea for 10.0.2
    + S8201433: Fix potential crash in BufImg_SetupICM
    + S8201495: [Zero] Reduce limits of max heap size for boot JDK
    on s390
    + S8201509: Zero: S390 31bit atomic_copy64 inline assembler is
    wrong
    + S8201788: Number of make jobs wrong for bootcycle-images
    target
    + S8202210: jlink uses little-endian for big-endian
    cross-compilation targets
    + S8202262: libjsig.so not linked with extra linker flags from
    configure
    + S8202522: Switch to 'fcs' milestone for July CPU 2018 release
    + S8202540: Zero build is broken after JDK-8189871 (Refactor GC
    barriers to use declarative semantics)
    + S8202588: JDK 10.0.2 l10n resource file update
    + S8202784: generated-configure.sh changes missing in 8201495
    + S8203233: (tz) Upgrade time-zone data to tzdata2018e
    + S8203305: PPC64: Improve TM detection for enabling RTM on
    Linux / POWER9
    + S8203367: Upgrade to Freetype 2.9.1
    + S8203368: ObjectInputStream filterCheck method throws
    NullPointerException
    + S8203669: PPC64: Fix jtreg RTM tests after "8203305: Improve
    TM detection for enabling RTM on Linux / POWER9"
    + S8204322: += applied to String operands can provoke side
    effects
    + S8205491: adjust reflective access checks
- Removed patch:
  * bootcycle_jobs.patch
    + Fixed upstream
* Fri Jul  6 2018 fstrba@suse.com
- Remove the alternative for java before reinstalling it, if idlj
  is its slave (bsc#1096420)
* Wed Jun 27 2018 fstrba@suse.com
- Move idlj to *-devel package (bsc#1096420)
* Fri Jun 22 2018 fstrba@suse.com
- Added patch:
  * missing-return.patch
    + fix no-return-in-nonvoid-function
* Thu Apr 19 2018 guillaume.gardet@opensuse.org
- Fix armv6 build with fix_armv6_build.patch
* Thu Apr 19 2018 fstrba@suse.com
- OpenJDK 10.0.1 (April 2018 CPU)
  * Security fixes:
    + S8194238: Trying exceptions in MethodHandles (CVE-2018-2826,
    bsc#1090197)
    + S8194233: Improve support for array handles (CVE-2018-2825,
    bsc#1090196)
    + S8192025: Less referential references (CVE-2018-2814,
    bsc#1090032)
    + S8189997: Enhance keystore mechanisms (CVE-2018-2794,
    bsc#1090024)
    + S8189977: Improve permission portability (CVE-2018-2795,
    bsc#1090025)
    + S8192757: Improve stub classes implementation (CVE-2018-2815,
  bsc#1090033)
    + S8189993: Improve document portability (CVE-2018-2799,
    bsc#1090029)
    + S8189989: Improve container portability (CVE-2018-2798,
    bsc#1090028)
    + S8189985: Improve tabular data portability (CVE-2018-2797,
    bsc#1090027)
    + S8189981: Improve queuing portability (CVE-2018-2796,
    bsc#1090026)
    + S8189969: Manifest better manifest entries (CVE-2018-2790,
    bsc#1090023)
  * Security-In-Depth fixes:
    + S8182362: Update CipherOutputStream Usage
    + S8183032: Upgrade to LittleCMS 2.9
    + S8189123: More consistent classloading
    + S8190478: Improved interface method selection
    + S8190877: Better handling of abstract classes
    + S8191696: Better mouse positioning
    + S8192030: Better MTSchema support
    + S8193409: Improve AES supporting classes
    + S8193414: Improvements in MethodType lookups
  * Fixes:
    + S8160104: CORBA communication improvements
    + S8163237: Restrict the use of EXPORT cipher suites
    + S8172525: Improve key keying case
    + S8174756: Extra validation for public keys
    + S8174962: Better interface invocations
    + S8175075: Add 3DES to the default disabled algorithm security
    property
    + S8175932: Improve host instance supports
    + S8176450: Revise default document styling
    + S8178449: Improve LDAP logins
    + S8178458: Better use of certificates in LDAP
    + S8178466: Better RSA parameters
    + S8179533: Cleaner print job handling
    + S8179990: Cleaner palette entry handling
    + S8180011: Cleaner native graphics device handling
    + S8180015: Cleaner AWT robot handling
    + S8180020: Improve SymbolHashMap entry handling
    + S8180869: Cleaner image file reading handling
    + S8180877: More deeply colored ICC spaces
    + S8181664: Improve JVM UTF String handling
    + S8181670: Improve implementation of keystores
    + S8182125: Improve reliability of DNS lookups
    + S8182387: Improve PKCS usage
    + S8182601: Improve usage messages
    + S8185292: Stricter key generation
    + S8185325: Improve GTK initialization
    + S8186032: Disable XML Signatures signed with EC keys less
    than 224 bits
    + S8186080: Transform XML interfaces
    + S8186212: Improve GSS handling
    + S8186600: Improve property negotiations
    + S8186606: Improve LDAP lookup robustness
    + S8186998: Improve JMX supportive features
    + S8187496: Possible memory leak in
    java.apple.security.KeychainStore.addItemToKeychain
    + S8189284: More refactoring for deserialization cases
    + S8189989: Improve container portability
    + S8190227: Forward port 8188880 to JDK10CPU
    + S8190289: More refactoring for client deserialization cases
    + S8190789: sun/security/provider/certpath/LDAPCertStore/
    /TestURICertStoreParameters.java fails after JDK-8186606
    + S8191142: More refactoring for naming deserialization cases
    + S8191358: Restore TSA certificate expiration check
    + S8191907: PPC64 and s390 parts of JDK-8174962: Better
    interface invocations
    + S8192789: Avoid using AtomicReference in
    sun.security.provider.PolicyFile
    + S8193683: Increase the number of clones in the CloneableDigest
    + S8194259: keytool error: java.io.IOException: Invalid secret
    key format
    + S8194540: Change version number to 10.0.1
    + S8194542: Update milestone to ea for 10.0.1+1
    + S8196289: Update src/java.desktop/share/legal/lcms.md for
    LCMS 2.9
    + S8196426: Update milestone to fcs for 10.0.1+3
    + S8197443: ArrayIndexOutOfBoundsException in
    UcryptoException.getError
    + S8198746: JDK 10.0.1 L10n resource file update
    + S8200359: (tz) Upgrade time-zone data to tzdata2018d
* Thu Apr 12 2018 fstrba@suse.com
- Build client JVM on arm v6 and lower. Server JVM does not work on
  anything lower then arm v7.
* Tue Mar 20 2018 fstrba@suse.com
- Official OpenJDK 10 release
  * remove the "-internal" postfix of the version string
  * remove the build number from rpm version of the package
  * take tarballs from the jdk-update project, since the CPUs will
    be delivered there
* Thu Mar  8 2018 fstrba@suse.com
- Update to tag jdk-10+46
- Fixes:
  + S8198950: AArch64: org.openjdk.jcstress.tests.varhandles.DekkerTest
    fails
* Fri Mar  2 2018 fstrba@suse.com
- Modified patch:
  * system-pcsclite.patch
    + Fix merge error in the patch
* Wed Feb 28 2018 fstrba@suse.com
- Update to tag jdk-10+45
  * Fixes:
    + S8198658: Docs still point to JDK 9 docs
* Wed Feb 21 2018 fstrba@suse.com
- Update to tag jdk-10+44
  * Fixes:
    + S8196383: JDK 10 L10n resource file update - msgdrop 20
    + S8196602: Change HeapRegionClosure to comply to naming
    conventions
    + S8196883: G1RemSet::refine_card_concurrently doesn't need to
    check for cards in collection set
    + S8197493: [Backout] JDK-8196602 Change HeapRegionClosure to
    comply to naming conventions
    + S8197968: [Backout] JDK-8196883
    G1RemSet::refine_card_concurrently doesn't need to check for
    cards in collection set
* Fri Feb  9 2018 fstrba@suse.com
- Update to tag jdk-10+43
  * Fixes:
    + S8194764: javac incorrectly flags deprecated for removal
    imports
    + S8195837: (tz) Upgrade time-zone data to tzdata2018c
    + S8195973: Update JDK 10 repo for FCS build
    + S8196288: Update src/java.desktop/share/legal/libharfbuzz.md
    for harfbuzz
    + S8196503: PPC64: vtableStubs gtest fails after 8174962
    + S8196678: avoid printing uninitialized buffer in
    os::print_memory_info on AIX
    + S8196717: remove xmlresolver.md
* Fri Feb  2 2018 fstrba@suse.com
- Update to tag jdk-10+42
  * Fixes:
    + S8191915: JCK tests produce incorrect results with C2
    + S8193840: Add compiler/c2/Test8007294.java to the problem list
    + S8194739: Zero port of 8174962: Better interface invocations
    + S8195852: The usage of permissions in Desktop API should be
    clarified
    + S8195859: AArch64: vtableStubs gtest fails after 8174962
    + S8195970: Crash passing null to a VarHandle
    + S8196136: AArch64: Correct register use in patch for
    JDK-8195685
    + S8196221: AArch64: Mistake in committed patch for JDK-8195859
    + S8196287: Update src/java.desktop/share/legal/libpng.md for
    libpng 1.6.34
    + S8196295: [Graal] remove unused org.graalvm.options package
    + S8196296: Lucene test crashes C2 compilation
- Removed patches:
  * JDK-8194739-zero.patch
  * JDK-8196136-aarch64.patch
    + Integrated upstream
* Fri Jan 26 2018 fstrba@suse.com
- Update to tag jdk-10+41
  * Fixes:
    + S8189761: COMPANY_NAME, IMPLEMENTOR, BUNDLE_VENDOR, VENDOR,
    but no configure flag
    + S8191839: ModuleElement.DirectiveVisitor :: visit() method
    behavior is deviating from the spec
    + S8192004: InspectedFrame.materializeVirtualObjects only
    updates locals with new objects
    + S8194135: The content in textArea can not be pasted after
    clicking "Copy" button.
    + S8194229: tools/jmod/JmodTest.jtr fails when no privilege to
    create sym link on windows
    + S8194307: KeyStore#getInstance with custom LoadStoreParameter
    succeeds with invalid password
    + S8194869: [TESTBUG][aix, s390] Adapt tests to platforms.
    + S8194982: 2 Null pointer dereference defect groups related to
    ProjNode::is_uncommon_trap_if_pattern()
    + S8194989: 2 Null pointer dereference defect groups caused by
    Dependencies::DepValue::as_klass()
    + S8194991: Null pointer dereference caused by
    c2v_getNextStackFrame
    + S8194992: Null pointer dereference in MultiNode::proj_out
    related to loopexit()
    + S8195478: sun/text/resources/LocaleDataTest.java fails with
    java.lang.Exception
    + S8195615: libsplashscreen linux ppc64le build error after
    libpng update
    + S8195685: AArch64: AArch64 cannot build with JDK-8174962
    + S8195823: Buffers given to response body subscribers should
    not contain unprocessed HTTP data
- Modified patch:
  * JDK-8194739-zero.patch
    + Version that is commited to the jdk10 repository
  * jdk10-gcc6.patch
    + Rediff to changed context
- Removed patch:
  * JDK-8195685-aarch64.patch
    + Integrated upstream
- Added patch:
  * JDK-8196136-aarch64.patch
    + S8196136: AArch64: Correct register use in patch for
    JDK-8195685
* Thu Jan 25 2018 fstrba@suse.com
- Modified patch:
  * JDK-8195685-aarch64.patch
    + Incorporate S8196136: AArch64: Correct register use in patch
    for JDK-8195685
* Mon Jan 22 2018 fstrba@suse.com
- Removed patch:
  * revert-8174962-for-zero.patch
    + a proper fix for ZERO exists
- Added patch:
  * JDK-8194739-zero.patch
    + S8194739: Zero port of 8174962: Better interface invocations
* Sat Jan 20 2018 fstrba@suse.com
- Removed patch:
  * revert-8174962-for-aarch64.patch
    + a proper fix for aarch64 exists
- Added patches:
  * JDK-8195685-aarch64.patch
    + S8195685, AArch64 cannot build with JDK-8174962
  * revert-8174962-for-zero.patch
    + revert "S8174962, CVE-2018-2582: Better interface invocations"
    for ZERO. The patch misses ZERO parts and causes crash
  during build.
* Thu Jan 18 2018 fstrba@suse.com
- Update to tag jdk-10+40 (January 2018 CPU) - bsc#1076366
  * Security fixes:
    + S8172525, CVE-2018-2579: Improve key keying case
    + S8174962, CVE-2018-2582: Better interface invocations
    + S8178449, CVE-2018-2588: Improve LDAP logins
    + S8182125, CVE-2018-2599: Improve reliability of DNS lookups
    + S8182387, CVE-2018-2603: Improve PKCS usage
    + S8182601, CVE-2018-2602: Improve usage messages
    + S8185292, CVE-2018-2618: Stricter key generation
    + S8185325, CVE-2018-2641: Improve GTK initialization
    + S8186212, CVE-2018-2629: Improve GSS handling
    + S8186600, CVE-2018-2634: Improve property negotiations
    + S8186606, CVE-2018-2633: Improve LDAP lookup robustness
    + S8186998, CVE-2018-2637: Improve JMX supportive features
    + S8189284, CVE-2018-2663: More refactoring for deserialization
    cases
    + S8190289, CVE-2018-2677: More refactoring for client
    deserialization cases
    + S8191142, CVE-2018-2678: More refactoring for naming
    deserialization cases
  * Security-In-Depth fixes:
    + S8160104: CORBA communication improvements
    + S8174756: Extra validation for public keys
    + S8175932: Improve host instance supports
    + S8176450: Revise default document styling
    + S8178458: Better use of certificates in LDAP
    + S8178466: Better RSA parameters
    + S8179533: Cleaner print job handling
    + S8179990: Cleaner palette entry handling
    + S8180011: Cleaner native graphics device handling
    + S8180015: Cleaner AWT robot handling
    + S8180020: Improve SymbolHashMap entry handling
    + S8180869: Cleaner image file reading handling
    + S8180877: More deeply colored ICC spaces
    + S8181664: Improve JVM UTF String handling
    + S8181670: Improve implementation of keystores
    + S8186080: Transform XML interfaces
  * Fixes:
    + S8075939: Stream.flatMap() causes breaking of
    short-circuiting of terminal operations
    + S8163237: Restrict the use of EXPORT cipher suites
    + S8175542: JMX: Not enough JDP packets received
    + S8179700: Exceptions thrown in StartManagementAgent.java
    + S8181047: Add comment to technical terms that shall not be
    translated
    + S8181878: javadoc should support/ignore --add-opens
    + S8187946: Support ISO 4217 Amendments 163 and 164
    + S8188145: MethodHandle resolution should follow JVMS sequence
    of lookup by name & type before type descriptor resolution
    + S8189146: Have use of "var" in 9 and earlier source versions
    issue a warning for type declarations
    + S8190789: sun/security/provider/certpath/LDAPCertStore/
    /TestURICertStoreParameters.java fails after JDK-8186606
    + S8191350: jdk/internal/reflect/CallerSensitive/CheckCSMs.java
    test fails when -Xmx512m set
    + S8191907: PPC64 and s390 parts of JDK-8174962: Better
    interface invocations
    + S8193597: sun/nio/cs/TestStringCoding.java fails
    intermittently with getBytes(csn) failed -> GBK
    + S8193664: AppCDS tests should use
  - XX:+UnlockCommercialFeatures when running with commercial JDK
    + S8193683: Increase the number of clones in the CloneableDigest
    + S8193767: Improve javadoc in ResourceBundle working with
    modules
    + S8193933: Export ClassLoaderData claim state to support
    interleaved object traversal
    + S8194044: Regression manual Test
    javax/swing/JFileChooser/8067660/FileChooserTest.java fails
    + S8194286: tools/launcher/FXLauncherTest.java fails with
    java.lang.UnsatisfiedLinkError
    + S8194287: tools/launcher/RunpathTest.java fails with
    java.lang.NullPointerException
    + S8194717: JDK10 L10n resource file update - msgdrop 10
    + S8194883: Unhandleable Push Promises should be cancelled
    + S8194914: Compilation fails with "node not on backedge" in
    OuterStripMinedLoopNode::adjust_strip_mined_loop
    + S8194929: Unreferenced FileDescriptors not closed
    + S8194953: doclet corrupts HTML files when adding navbar
    + S8194955: Warn when default HTML version is used
    + S8194959: Correct test tag to move bugid from @test to @bug
    + S8194963: SystemDictionary::link_method_handle_constant()
    can't link MethodHandle.invoke()/invokeExact()
    + S8194988: 8 Null pointer dereference defect groups related to
    MultiNode::proj_out()
    + S8194993: Loop Strip Mining has some leftover debugging code
    + S8195072: Update ASM 3rd party legal copyright to 6.0
    + S8195094: Fix type-O in "8159422: Very high Concurrent Mark
    mark stack contention"
    + S8195123: Very large regressions in Octane benchmarks using
    10-b39
    + S8195138: The asynchronous Http1HeaderParser doesn't handle
    all line folds correctly
    + S8195153: [test] runtime/6981737/Test6981737.java shouldn't
    check 'java.vendor' and 'java.vm.vendor' properties
- Added patch:
  * revert-8174962-for-aarch64.patch
    + revert "S8174962, CVE-2018-2582: Better interface
    invocations" for aarch64 and zero. The patch misses aarch64
    and zero parts and causes crashes during the build on those
    architectures.
- Modified patch:
  * disable-doclint-by-default.patch
    + rediff to changes in context
* Tue Jan 16 2018 fstrba@suse.com
- Recommend tzdata-java8 instead of depending on it. This fixes
  build cycles.
* Fri Jan 12 2018 fstrba@suse.com
- Update to upstream tag jdk-10+39
  * Fixes
    + S8179858: jshell tool: sync nomenclature from reference to
    online /help
    + S8185986: redundant/obsolete overview.html pages
    + S8187487: crash with classes with same binary name
    + S8187805: bogus RuntimeVisibleTypeAnnotations for unused
    local in a block
    + S8187951: Update javax.lang.model.SourceVersion for "var" name
    + S8188649: javadoc -encoding doesn't work when using the old
    doclet API
    + S8189704: broken links in the javax/xml/namespace package
    + S8191362: [Graal] gc/g1/TestShrinkAuxiliaryData tests crash
    with "assert(check_klass_alignment(result)) failed: address
    not aligned"
    + S8191637: Interface with defaults invalid compiler warning
    for Serializable
    + S8192007: javadoc @uses and @provides tags in the modules
    documentation appears before the first-sentence summary of the
    service type.
    + S8193567: Conversion of comparison nodes affects local slots
    in optimistic continuation
    + S8193607: Test failure with java.lang.ClassNotFoundException:
    compiler.tiered.LevelTransitionTest
    + S8193608: Quarantine
    test/hotspot/jtreg/compiler/codegen/Test6896617.java until
    JDK-8193479 is fixed
    + S8193671: Default Methods tab under Method Summary includes
    static methods
    + S8193673: Regression manual Test
    javax/swing/JFileChooser/6515169/bug6515169.java fails
    + S8194067: [Testbug] serviceability/sa/Jhsdb* tests can't
    tolerate unrelated warnings
    + S8194069: doclint throws missing comment warnings on lines
    which can't even have javadoc
    + S8194232: Container memory not properly recognized.
    + S8194258: PPC64 safepoint mechanism: Fix initialization on
    AIX and support SIGTRAP
    + S8194271: jaotc crashes with --debug flag
    + S8194494: SHA-512 stub uses AVX 2 instructions on
    non-supporting CPUs
    + S8194662: Problem list com/sun/jndi/ldap/LdapTimeoutTest.java
    + S8194666: ProblemList update for bugid associated with
    PreferredKey.java, ConcurrentHashMapTest and
    SSLSocketParametersTest.sh
    + S8194681: G1 uses young free cset time when reporting
    non-young free cset times
    + S8194742: Writing replay data crashes: task is NULL
    + S8194824: Add
    gc/stress/gclocker/TestGCLockerWithParallel.java to the
    ProblemList file
    + S8194836: delta apply changesets for JDK-8192885 and
    JDK-8175883
    + S8194901: remove interim code from javax.tools.ToolProvider
* Sun Jan  7 2018 fstrba@suse.com
- Update to upstream tag jdk-10+38
  * Fixes
    + S8183964: Bad lexing of javadoc comments (change in
    parsing/rendering of backslashes in javadoc)
    + S8184431: References to @sun.com
    + S8191852: Null pointer dereference in ciKlass::get_Klass of
    ciKlass.hpp:58
    + S8191854: Null pointer dereference in methodData.hpp:462
    + S8191988: JDK-8190862 work for arch s390
    + S8192837: Need new test for release info file
    + S8193125: javac should not compile a module if it requires
    java.base with modifiers
    + S8193371: Use Dynalink REMOVE operation in Nashorn
    + S8193427: serviceability/sa/ClhsdbPrintStatics.java fails:
    java.lang.RuntimeException: '_jfr_checkpoints' missing from
    stdout/stderr
    + S8193428: serviceability/sa/ClhsdbSymbol.java fails:
    java.lang.RuntimeException: 'UsageTracker' missing from
    stdout/stderr
    + S8193435: Remove pre-1.2 SecurityManager text from
    java.awt.Toolkit
    + S8193468: [PIT][TEST BUG]:
    java/awt/FileDialog/MoveToTrashTest.java fails on Linux
    + S8193506: serviceability/sa/TestClassDump.java fails in
    OpenJDK build
    + S8193568: @LastModified tag in license header
    + S8193699: aarch64 fails to build after 8167372
    + S8193856: takeWhile produces incorrect result with elements
    produced by flatMap
    + S8194058: [TESTBUG] serviceability/sa/ClhsdbWhere.java fails
    to find method 'sleep' in output
    + S8194482: Fix SIGSEGV in print_threads_compiling.
* Fri Dec 22 2017 fstrba@suse.com
- Update to upstream tag jdk-10+37
  * Fixes
    + S8133805: Remove the bot_updates parameter from G1Allocator's
    allocation methods
    + S8154405: AccessControlException by URLPermission check
    + S8165603: runtime/appcds/UseAppCDS.java: failed to clean up
    files after test when running with agentvm
    + S8190869: C2: missing strength reduction of Math.pow(x, 2.0D)
    to x*x
    + S8190934: Regressions on Haswell Xeon due to JDK-8178811
    + S8190984: tools/launcher/TestXcheckJNIWarnings.java WARNING
    was found in the output
    + S8191229:
    serviceability/jvmti/GetOwnedMonitorInfo/GetOwnedMonitorInfoTest.java
    fails with NoClassDefFoundError
    + S8191788: add jdk.internal.vm.compiler to --limit-modules if
  - Djvmci.Compiler=graal is in the command line
    + S8192966: HttpClient should reuse TCP connection for h2c
    connections
    + S8192971: LockCompilationTest fails intermittently
    + S8192985: SA: Test cases for the clhsdb 'inspect', 'scanoops'
    and 'printas' commands
    + S8192989: runtime/appcds/javaldr/ArrayTest.java crashes with
    assert(k->is_instance_klass())
    + S8193053: jvm crash by G1CMBitMapClosure::do_addr
    + S8193124: SA: Testcases for clhsdb jdis and findpc commands
    + S8193135: get rid of redundant _smr_ prefix/infix in
    ThreadSMRSupport stuff
    + S8193222: EnsureLocalCapacity() should maintain capacity
    requests through multiple calls
    + S8193271: ProblemList
    tools/launcher/TestXcheckJNIWarnings.java
    + S8193323: Crash in "failed dependencies, but counter didn't
    change" with enabled UseJVMCICompiler
    + S8193363: TestDumpReplay.java fails with product builds
    + S8193365: Improve interoperability between HTTP Client's
    BodyPublisher/BodySubscriber and Flow.Subscriber/Publisher
    + S8193386: CompressedClassSize too large with MaxMetaspace
    + S8193407: jdk/hs fails Solaris slowdebug test-image build
    + S8193439: Update Graal
    + S8193491: JavaImporter fails to resolve method elements
    within functions, that contain too many statements
    + S8193508: Expressions in split literals must never be
    optimistic
    + S8193512: Remove remnants of javah from jdk/jdk repo
    + S8193515: AIX: new Harfbuzz 1.7.1 version fails to compile
    with xlC
    + S8193518: C2: Vector registers sometimes corrupted at
    safepoint
    + S8193622: JFR test TestUnloadingEventClass.java times out
    intermittently
    + S8193698: Null handling in BodyPublisher, BodyHandler, and
    BodySubscriber convenience static factory methods
    + S8193758: Update copyright headers of files in src tree that
    are missing Classpath exception
    + S8193764: Cannot set COMPANY_NAME when configuring a build
    + S8193779: Fix copyright header in nashorn builtin scripts
- Removed patch:
  * remove_javah_for_real.patch
    + fixed upstream
* Fri Dec 15 2017 fstrba@suse.com
- Update to upstream tag jdk-10+36
  * Fixes
    + S5016517: Replace plaintext passwords by hashed passwords for
    out-of-the-box JMX Agent
    + S8006887: Comment about LIR_OprDesc.value in c1_LIR.hpp is
    incorrect
    + S8034254: Don't use binary testing files broken.jar
    + S8069338: Implement sharedScopeCall for optimistic types
    + S8080225: FileInput/OutputStream/FileChannel cleanup should
    be improved
    + S8080345: With perm gen gone, perfdata counter
    sun.gc.policy.generations should be 2, not 3
    + S8087339: The code heap might use different alignment for
    committed size and reserved size
    + S8140281: add no-arg Optional.orElseThrow() as preferred
    alternative to get()
    + S8145579: SimpleThresholdPolicy assumes non-trivial methods
    to be trivial
    + S8146537: TrayIcon Action Listener doesnt work in WIndows 10
    + S8148421: Transport Layer Security (TLS) Session Hash and
    Extended Master Secret Extension
    + S8149402: "-group" option issue for classes from default
    package
    + S8162989: jshell tool: /edit with external editor leaks files
    in /tmp
    + S8164407: Add module support for -link and -linkoffline
    javadoc option
    + S8165736: Error message should be shown when JVMTI agent
    cannot be attached
    + S8165996: PKCS11 using NSS throws an error regarding
    secmod.db when NSS uses sqlite
    + S8167108: inconsistent handling of SR_lock can lead to crashes
    + S8170244: Update UseAVX after cpu feature detection to use
    more default mapping
    + S8170495: JNI primitive type mismatch in
    SocketDispatcher.c:187
    + S8171826: Comparator.reverseOrder(c) mishandles singleton
    comparators
    + S8174101: Bootclasspath append should not invalidate CDS
    archive
    + S8176841: Additional Unicode Language-Tag Extensions
    + S8177681: Remove methods
    Runtime.getLocalized{Input,Output}Stream
    + S8177758: Regression in java.awt.FileDialog
    + S8178070: duplicate entries in package table
    + S8178401: Various audio files writers do not close file
    streams properly
    + S8178497: Bug in MutableNUMASpace::ensure_parsability
    + S8179026: Remove explicit code cache options processing
    + S8179083: Uninitialized notifier in Java Monitor Wait tracing
    event
    + S8179244: Assert failed in instanceMirrorKlass.inline.hpp
    + S8181118: update java/time tests to use RandomFactory from
    the top level testlibrary
    + S8181289: Invalid HTML 5 in AWT/Swing docs
    + S8181633: Vectorization fails for some multiplication with
    constant cases
    + S8181659: Create an alternative fix for JDK-8167102, whose
    fix was backed out
    + S8182050: assert(_whole_heap.contains(p)) failed: Attempt to
    access p out of bounds of card marking array's _whole_heap
    + S8182307: Error during JRMP connection establishment
    + S8182401: Verification error for enclosing instance capture
    inside super constructor invocation
    + S8182410: missing 'title' in
    api/javax/swing/plaf/synth/doc-files/componentProperties.html
    + S8182610: Update specification of service providers for
    IIORegistry and ServiceRegistry
    + S8183508: multi_tsc.html should be updated
    + S8183518: Premature deprecation of Event/InputEvent/KeyEvent
    in Java 9
    + S8183743: Umbrella: add overloads that take a Charset
    parameter
    + S8183960: Upgrade to libpng 1.6.34
    + S8184361: AOT lib at jdk/lib/libjava.base-coop.so seems to
    override -XX:AOTLibrary=
    + S8184947: ZipCoder performance improvements
    + S8184982: SA: Running ClassDump on a simple java program
    generates NullPointerException
    + S8185027: Typo in
    java.net.URLClassLoader.findResources(String) method
    documentation
    + S8185582: Update Zip implementation to use Cleaner, not
    finalizers
    + S8185591: guarantee(_byte_map[_guard_index] == last_card)
    failed: card table guard has been modified
    + S8185796: jstack and clhsdb jstack should show lock objects
    + S8186027: C2: loop strip mining
    + S8186461: Zero's atomic_copy64() should use SPE instructions
    on linux-powerpcspe
    + S8186787: clang-4.0 SIGSEGV in Unsafe_PutByte
    + S8187073: The java.util.logging.Level.findLevel() will not
    correctly find a Level by it's int value
    + S8187227: Zero should use compiler built-ins for atomics on
    linux-m68k
    + S8187254: MethodType allows unvalidated parameter types
    + S8187280: Remove unused methods from StubQueue
    + S8187819: gc/TestFullGCALot.java fails on jdk10 started with
    "-XX:-UseCompressedOops" option
    + S8187936: Automatically selecting a new JTree node in a model
    listener can cause unusual behavior
    + S8188083:
    NullPointerExcpn-java.awt.image.FilteredImageSource.startProduction
    JDK-8079607
    + S8188221: Return type profiling is not performed from aarch64
    interpreter
    + S8188789: Update JDK 9.0.1 and Future OpenJDK bundle names
    + S8188791: Move AppCDS from closed repo to open repo
    + S8188836: Upgrade to Harfbuzz 1.7.1 in JDK 10
    + S8188877: Improper synchronization in offer_termination
    + S8189116: Give the jdk.internal.vm.compiler.management only
    the permissions it really needs to expose the bean
    + S8189131: Open-source the Oracle JDK Root Certificates
    + S8189134: New system properties for the default Locale
    extensions
    + S8189248: Jshell: error with mutually dependent snippets,
    when one must be replaced
    + S8189439: Parameters type profiling is not performed from
    aarch64 interpreter
    + S8189596: AArch64: implementation for Thread-local handshakes
    + S8189656: The Windows L&F should be moved out from the shared
    folder
    + S8189733: Cleanup Full GC setup and tear down
    + S8189778: Jshell crash on tab for StringBuilder.append(
    + S8189782: com.sun.tools.javac.api.JavacTool.isSupportedOption
    misreports number of arguments consumed
    + S8189793: [s390]: Improve String compress/inflate by
    exploiting vector instructions
    + S8189809: Large performance regression in Swing text layout
    + S8190278: ClassCastException is thrown by java.util.Scanner
    when a NumberFormatProvider is used.
    + S8190308: Implementation: JEP 316: Heap Allocation on
    Alternative Memory Devices
    + S8190408: Run G1CMRemarkTask with the appropriate amount of
    threads instead of starting up everyone
    + S8190426: Lazily initialize refinement threads with
    UseDynamicNumberOfGCThreads
    + S8190484: Move jvm.h, jmm.h et al to hotspot/*/include
    + S8190494: Different results with UseAVX=3 when calling
    AVX-512 native function via JNI
    + S8190515: java.awt.Desktop.moveToTrash(File) prompts on
    Windows 7 but not on Mac
    + S8190729: Adjustment to anonymous metadata space chunk
    allocation algorithm
    + S8190800: Support vectorization of Math.sqrt() on floats
    + S8190809: JVM crashes while generating appcds for classpath
    with empty directory entry
    + S8190823: Broken link in org/w3c/dom/ls/
    + S8190837: BasicType and BasicTypeSize should refer to HotSpot
    values
    + S8190918: Retrieve the region specific data regardless of
    language in locale
    + S8190980: Develop test cases and collect test pass rate
    + S8191030: @value Tags are not resolved by javadoc 9.
    + S8191033: Regression in logging.properties: specifying
    .handlers= for root logger (instead of handlers=) no longer
    works
    + S8191052: [Graal] java/lang/invoke/CallSiteTest.java
    intermittently fails with "Failed dependency of type
    call_site_target_value" when running with Graal as JIT
    + S8191054: Remove the Native-Header Tool (javah)
    + S8191078: Wrong "Package not found" warning
    + S8191129: AARCH64: Invalid value passed to critical JNI
    function
    + S8191153: assert(u_ctrl != blk1 && u_ctrl != blk2) failed:
    won't converge
    + S8191202: Remove duplicated jmm.h
    + S8191216: SimpleTimeZone.clone() has a data race on cache
    fields
    + S8191227: issues with unsafe handle resolution
    + S8191232:
    compiler/intrinsics/bigInteger/TestMultiplyToLen.java fails
    with java.lang.Exception: Failed
    + S8191273: applications/ctw/modules tests fail intermittently
    + S8191301: JavaImporter fails to resolve imported elements
    within functions, that contain too many statements
    + S8191313: compiler/runtime/SpreadNullArg.java fails in tier1
    + S8191324: SA cleanup -- part 2
    + S8191349: Add a new method in j.t.f.DateTimeFormatter to
    reflect Unicode extensions
    + S8191360: Lookup of critical JNI method causes duplicate
    library loading with leaking handler
    + S8191436: ListSelectionModel.setSelectionMode() underspecified
    + S8191437: AOT doesn't work easily after thread local
    handshakes
    + S8191455: jdk/jshell/StartOptionTest.java and
    jdk/jshell/ToolProviderTest.java failed after changeset e0f08a
    + S8191456: jdk/jshell/ExternalEditorTest.java
    testStatementMush() failure
    + S8191494: Refresh incubating HTTP Client
    + S8191504: [TESTBUG] CDSTestUtils.isUnableToMap() should check
    OptionalData region mapping failure
    + S8191538: SA: tests for clhsdb commands: vmstructsdump,
    field, symboltable and symbol
    + S8191564: Refactor GC related servicability code into GC
    specific subclasses
    + S8191636: [Windows] jshell tool: Wrong character in /env
    class-path command crashes jshell
    + S8191639: NPE from BasicListUI.Actions.getNextPageIndex
    + S8191653: Test failures in BootAppendTests - missing
    jdk.internal.vm.compiler module
    + S8191658: SA: Testcases for attach, detach, reattach and
    Jhisto commands
    + S8191683: Compile problem on ARM after JDK-8043070
    + S8191688: Assert failed in > 200 tests: failed dependencies,
    but counter didn't change
    + S8191706: Add Reader::transferTo(Writer)
    + S8191707: Options with invalid values are incorrectly treated
    as obsolete and ignored
    + S8191747: [TESTBUG] runtime/appcds/DumpClassList.java and
    ProhibitedPackage.java fail on product bits
    + S8191767: Memory leak in JabSwitch
    + S8191768: Introduce a concurrency factor to be able to scale
    up or down jtreg concurrency when running Hotspot tests
    + S8191769: AARCH64: Fix hint instructions encoding
    + S8191770: [ppc64] Fix CDS: don't rewrite invokefinal if
    DumpSharedSpaces
    + S8191779: LogCompilation throws java.lang.Error: scope
    underflow
    + S8191782: Missing deprecated options in
    VMDeprecatedOptions.java
    + S8191787: move private inline functions from
    thread.inline.hpp -> thread.cpp
    + S8191789: migrate more Thread-SMR stuff from thread.[ch]pp ->
    threadSMR.[ch]pp
    + S8191803: [TEST_BUG] :
    sanity/client/SwingSet/src/ProgressBarDemoTest.java failed
    with "Wait "greater then 1349" state to be reached
    + S8191814: Marlin rasterizer spends time computing geometry
    for stroked segments that do not intersect the clip
    + S8191821: Finer granularity for GC verification
    + S8191846: jstat prints debug message when debugging is
    disabled
    + S8191858: Add missing includes in memoryManager.hpp
    + S8191860: Add perfData.inline.hpp
    + S8191861: Move and refactor hSpaceCounters
    + S8191862: Warn about UseNUMA/UseLargePages only when using
    ParallelGC
    + S8191863: [s390] Fix CDS: some bytecode rewriting doesn't
    depend on RewriteControl
    + S8191864: Provide a public destructor for WorkGang
    + S8191867: Module attribute in 54.0+ class file cannot
    contains a requires java.base with ACC_TRANSITIVE or
    ACC_STATIC_PHASE
    + S8191868: IdealGraphVisualizer: "ant build/run" fails due to
    outdated bootstrap.url
    + S8191870: Remove badJNIHandle
    + S8191872: (fs) UnixNativeDispatcher conditionally compiles in
    support for high precision timestamps
    + S8191887: assert(b->is_Bool()) in PhaseIdealLoop::clone_iff()
    due to Opaque4 node
    + S8191905: Add a REMOVE StandardOperation to Dynalink
    + S8191914: New SA test timeout on windows
    + S8191919: Include TestJhsdbJstackLock.java in ProblemList.txt
    + S8191927: Enable AppCDS for custom loaders on all 64-bit
    Linux and AIX
    + S8191943: [TESTBUG] docker/TestCPUAwareness fails on machine
    with 2 CPUs
    + S8191950: assertion failed: no insertions allowed
    + S8191961: SA: Remove left over quarantined SA tests due to
    8184042 from ProblemList.txt
    + S8191996: VM startup fails with CodeCacheExpansionSize=32768
    is outside the allowed range
    + S8192061: Clean up allocation.inline.hpp includes
    + S8192072: 8191782 fix for VMDeprecatedOptions.java missed
    DeferThrSuspendLoopCount and duplicated
    DeferPollingPageLoopCount
    + S8192154: JVM crashes inside some chroot environments on linux
    + S8192756: SIGSEGV in nmethod::new_native_nmethod
    + S8192762: LoopNode::verify_strip_mined() fails with "assert
    failed: only phis"
    + S8192807:
    testlibrary_tests/TestMutuallyExclusivePlatformPredicates.java
    fail due to new method in Platform.java
    + S8192810: EnableThreadSMRStatistics should be default off in
    release builds
    + S8192814: Update Graal
    + S8192818: [s390]: restoring register contents calculates
    wrong value
    + S8192821: Make LogCompilation into a maven project
    + S8192823: SA: Testcase for 'clhsdb source' command
    + S8192825: PPC64: Missing null check in C1 inline cache check
    + S8192833: JEP 322: Time-Based Release Versioning
    + S8192840:
    serviceability/dcmd/jvmti/AttachFailed/AttachNoEntry.java
    failing on Windows
    + S8192846: Support cmov vectorization for float
    + S8192850: method summary tables of inherited methods
    improperly list static interface methods
    + S8192863: jshell tool: /<id><tab> gives "No such command"
    + S8192866: [TESTBUG] Move UseAppCDS.java from the closed
    ProblemList.txt to the open one
    + S8192870: [Testbug] runtime/handshake/HandshakeTransitionTest
    throws NPE
    + S8192897: NPE occurs on clhsdb jstack
    + S8192898: AIX build broken after JDK-8190308
    + S8192908: -XX:+UseCountedLoopSafepoints alone doesn't disable
    strip mining with G1
    + S8192909: Invalid username or password in
    HashedPasswordFileTest.java
    + S8192933: Wrong generic type parameter in serialized form
    javadoc
    + S8192935: Fix EnumSet's SerializationProxy javadoc
    + S8192943: Optimize atomic accumulators using VarHandle
    getAndSet
    + S8192944: Miscellaneous changes imported from jsr166 CVS
    2017-12-08
    + S8192945: Need stable sort for MODULES entry in the release
    file
    + S8192950: Missing -nativepath for svc tests
    + S8192970: Element getters/setters with fixed key fail to link
    properly
    + S8192971: LockCompilationTest fails intermittently
    + S8192978: Missing checks and small fixes in jdwp library
    + S8192979: jshell tool: Online help text for commands is
    confusing
    + S8192983: gc/g1/TestVerifyGCType.java might fail on loaded
    machines
    + S8192986: Inconsistent handling of exploded modules in jlink
    + S8192987: keytool should remember real storetype if it is not
    provided
    + S8192988: keytool should support -storepasswd for pkcs12
    keystores
    + S8193009: compiler/c2/Test7029152.java crashes with SIGILL in
    java.lang.StringLatin1.indexOf with -XX:+UseJVMCICompiler
    + S8193012: Small cleanup of AWTEvent class
    + S8193034: Optimize URL.toExternalForm
    + S8193045: JDK-8190484 breaks build on Windows
    + S8193065: [TESTBUG] [TESTBUG]GCSharedStringsDuringDump.java:
    Exception in thread "main" java.lang.RuntimeException: String
    is not shared.
    + S8193068: Add gc/g1/TestVerifyGCType.java to problem list
    + S8193105: Print error code when map_memory_to_file() fails
    + S8193107: javadoc complains about empty module
    + S8193137: Nashorn crashes when given an empty script file
    + S8193142: Regression: ClassCastException: Type$ErrorType
    cannot be cast to Type$ArrayType
    + S8193156: Need to backout fixes for JDK-8058547, JDK-8055753,
    JDK-8085903
    + S8193159: Reduce the number of classes loaded due to
    NativeLibrary
    + S8193174: SubmissionPublisher invokes the Subscriber's
    onComplete before all of its submitted items have been
    published
    + S8193183: Fix format string in libdt_shmem/shmemBase.c
    + S8193191: Update JavacTestingAbstractProcessor for JDK 10
    + S8193192: jdeps --generate-module-info does not look at
    module path
    + S8193194: Update javax.lang.model.util visitors for 10
    + S8193208: Add additional licensing file for the JDK
    + S8193211: Update jtreg TEST.groups and ProblemList for
    client-libs
    + S8193225: [BACKOUT] fix for 8182307 Error during JRMP
    connection establishment
    + S8193256: Configuration and ModuleLayer findModule cleanup
    + S8193257: PPC64, s390 implementation for Thread-local
    handshakes
    + S8193258: Better usage of JDWP HEADER SIZE
    + S8193271: ProblemList
    tools/launcher/TestXcheckJNIWarnings.java
    + S8193296: Parser should not eagerly transform delete
    expressions
    + S8193298: Don't run javadoc with test.single
    + S8193370: Provide more user friendly defaults for HTTP/2
    client settings
    + S8193443: [s390]: EncodeISOArray generates wrong vector code
    + S8193454: ModuleDescriptor.{Requires,Exports,Open} toString
    should use toLowerCase(Local.ROOT)
    + S8193460: Take tools/launcher/TestXcheckJNIWarnings.java back
    off the ProblemList
    + S8193471: Startup regression due to JDK-8185582
    + S8193476: (jdeprscan) additional version updates for JDK 10
    + S8193489: Add information about local variable type inference
    to SourceVersion.RELEASE_10
    + S8193490:
    java/util/zip/ZipFile/ClearStaleZipFileInputStreams.java,
    FinalizeZipFile.java, TestCleaner.java, Collectible.java
    failed because cleaner can't finish
    + S8193503: javah launcher was not removed by JDK-8191054
    + S8193507: [REDO] Startup regression due to JDK-8185582
    + S8193525: Intermittent failures of TestModulePackages.java
- Removed patch:
  * linux_chroot_crash.patch
    + integrated upstream
- Added patch:
  * remove_javah_for_real.patch
    + Don't require javah for build
- Modified patch:
  * jaw-nojavah.patch
    + Patch out search for javah that is not part of jdk10
* Fri Dec  8 2017 fstrba@suse.com
- Update to upstream tag jdk-10+35
  * Fixes
    + S5031664: Increase thread safety of EventListenerList
    + S6354947: [Fmt-*] Clarify DecimalFormat description of
    FieldPosition use
    + S6415680: (bf) MappedByteBuffer.get() can provoke crash with
    EXCEPTION_IN_PAGE_ERROR
    + S8015667: Stream.toArray(IntFunction) ArrayStoreException
    should refer to component type of array
    + S8024352: MBeanOperationInfo accepts any int value as "impact"
    + S8034252: Fix non ASCII text file T6302184.java
    + S8043070: nmethod::verify_interrupt_point() shouldn't enter
    safepoint
    + S8043334: Typo in javax/swing/JComponent.html
    + S8059835: Optimistic splitting doesn't work with let and const
    + S8065838: compiler/relocations/TestPrintRelocations.java times
    out after 1920 seconds
    + S8068024: Null pointer dereference in
    jdk/src/macosx/native/apple/security/KeystoreImpl.m
    + S8133616: compiler error messages for dup single type, single
    static import switched
    + S8135178: importPackage not working even with load "Mozilla
    compatibility script"
    + S8139653: Freetype bundled on macosx, but not correctly linked
    + S8146115: Improve docker container detection and resource
    configuration usage
    + S8146977: Move the output "Building configuration X (matching
    Y)" to lower log level
    + S8158366: [macosx] Regression:
    closed/java/awt/dnd/RecognizedActionTest/RecognizedActionTest.html
    fails
    + S8159142: [hidpi] Visible artifacts in
    sun/java2d/SunGraphics2D/DrawImageBilinear.java
    + S8160303: parse_method_pattern only scans 254 chars
    + S8160406: Collection.toArray() spec should be explicit about
    returning precisely an Object[]
    + S8160548: Inconsistent inlining behavior with CompileOnly
    + S8169766: c1 + Xcomp reresolving call target every invocation
    + S8175795: configure should verify that system zlib contains
    needed functionality
    + S8175891: JrtPath::resolve off-by-one pre-sizing cause for
    memory pressure
    + S8176072: READING attributes are not available on TSF
    + S8176188:
    jdk/internal/misc/JavaLangAccess/NewUnsafeString.java
    failing since 9-b93
    + S8177290: add copy factory methods for unmodifiable List, Set,
    Map
    + S8177956: Add TEST_VM_OPTS as convenience for run-test
    arguments
    + S8177957: run-test summary lines look bad/misleading with long
    test names
    + S8178025: HiDPI with non-integer scale factor - SPANs in HTML
    are rendered overlapping each other
    + S8178048: [JVMCI] improve
    HotSpotResolvedJavaFieldImpl.hashCode()
    + S8178109: More useful documentation on /help
    + S8178427: NPE in Infer$CheckUpperBounds
    + S8178430: JMenu in GridBagLayout flickers when label text
    shows "..." and is updated
    + S8179554: make run-test does not respect ProblemList.txt
    + S8179555: make run-test should always use a fresh, clean
    JTwork directory
    + S8179603: create a jtreg test group for hotspot tests
    excluding application testing
    + S8181175: Stream.concat behaves like terminal operation
    + S8182108: javadoc makes up type variables for grandparent
    types
    + S8182284: G1Analytics uses uninitialized fields
    + S8182413: jdwp-protocol is generated without a DOCTYPE
    directive
    + S8182484: Remove 1024-bit default requirement from javadoc of
    java.security.interfaces.DSAKeyPairGenerator
    + S8182742: ClassLoader.getResourceXXX throws NPE when
    ClassLoader created by defineModulesWithXXX
    + S8184683: Add @since and default methods of Compiler Tree API
    methods
    + S8184690: add Collectors for collecting into unmodifiable
    List, Set, and Map
    + S8185130: jlink should throw error if target image and current
    JDK versions don't match
    + S8185369: Clean up the javadoc stylesheet
    + S8185451: Misleading 'cannot be accessed from outside package'
    diagnostic for inconsistent varargs override
    + S8185855: Debug exception stacks should be clearer
    + S8185983: Javac should reject TypeArguments on field access
    expression
    + S8185985: Html files in doc-files directories should be
    wrapped with standard header and footer
    + S8186057: TLS interoperability testing between different Java
    versions
    + S8186087: jar tool fails to create a multi-release jar when
    validating nested classes
    + S8186441: Change of behavior in the getMessage () method of
    the SOAPMessageContextImpl class
    + S8186480: Remove warning when AssumeMP is true and ergonomics
    determines to use one worker thread
    + S8186535: Remove deprecated pre-1.2 SecurityManager methods
    and fields
    + S8186540: [TESTBUG]
    serviceability/dcmd/jvmti/LoadAgentDcmdTest.java failed to
    clean up files in agentvm mode
    + S8186571: Implementation: JEP 307: Parallel Full GC for G1
    + S8186736: Spec clarifications for IllegalArgumentException
    throwing - ModuleLayer.defineX methods
    + S8186737: Lookup argument for StringConcatFactory.makeConcat &
    makeConcatWithConstants cannot have privileges less than
    PRIVATE
    + S8186961: Class.getFields() does not return fields of
    previously visited super interfaces/classes.
    + S8187118: Remove appending -cp path to the boot class path at
    AppCDS dump time
    + S8187119: Consolidate record_shared_class_loader_type() and
    record_result()
    + S8187222: ClassLoader.getSystemClassLoader not clear if
    recursive initialization leads to ISE or unspecified error
    + S8187237: Need to define the behaviour for 0 and 1 argument
    method type in StringConcatFactory.makeConcat
    + S8187367: Numerous swing display problems with scaled displays
    on Windows
    + S8187497: Redundant variable assignment in
    Java_sun_security_jgss_wrapper_GSSLibStub_getMic
    + S8187551: MessageFormat.setFormat(int, Format) AIOOBE not
    thrown when documented
    + S8187910: Charset MS950_HKSCS not supported in JDK 9
    + S8187947: A race condition in SubmissionPublisher
    + S8187954: Update JAX-WS RI integration to latest version
    + S8187985: Broken certificate number in debug output
    + S8188122: Path length limits on Windows leads to obscure class
    loading failures
    + S8188870: Bump classfile version number to 54
    + S8189099: JTReg now supports 256 jobs
    + S8189170: Add option to disable stack overflow checking in
    primordial thread for use with JNI_CreateJavaJVM
    + S8189171: Move GC argument processing into GC specific classes
    + S8189177: AARCH64: Improve _updateBytesCRC32C intrinsic
    + S8189204: Possible NPE in Component::getLocationOnScreen()
    + S8189331:
    java/io/Serializable/maskSyntheticModifier/MaskSyntheticModifierTest.java
    failed incorrect serialVersionUID
    + S8189389: Move heap creation into GC interface
    + S8189611: JarFile versioned stream and real name support
    + S8189734: Cleanup MarkSweep when G1 dependency is gone
    + S8189749: Devise strategy for making source level checks more
    uniform
    + S8189762: [TESTBUG] Create tests for JDK-8146115 container
    awareness and resource configuration
    + S8189871: Refactor GC barriers to use declarative semantics
    + S8189941: Implementation JEP 312: Thread-local handshake
    + S8190198: SA: Framework for writing 'jhsdb clhsdb' commands
    tests and testcases for some of the commands
    + S8190228: Remove redundant modifiers in java.desktop module.
    + S8190284: link-time-opt should not be using -fwhole-program
    + S8190307: SA tests for the clhsdb commands: universe,
    intconstant, type
    + S8190332: PngReader throws NegativeArraySizeException/OOM
    error  when IHDR width is very large
    + S8190348: [TESTBUG] Test
    javax/swing/JWindow/ShapedAndTranslucentWindows/PerPixelTranslucentCanvas.java
    fails
    + S8190357: NMT: Include metadata information in NMT final
    report when PrintNMTStatistics is on
    + S8190375: Java Crash in JavaBug.formatPos(I)Ljava/lang/String
    + S8190418: Stop generating jvmtiEnvStub and jvmtiEnvRecommended
    + S8190464: OpenJDK on macosx needs to bundle freetype
    + S8190552: Augment the Compiler API tree with APIs to represent
    HTML content
    + S8190674: sun/security/tools/jarsigner/TimestampCheck.java
    failed with java.nio.file.NoSuchFileException: ts2.cert
    + S8190817: deopt special-case for _return_register_finalizer is
    confusing and leads to bugs
    + S8190843: can not set/get extendedOptions to ServerSocket
    + S8190861: [TESTBUG]
    javax/swing/JWindow/ShapedAndTranslucentWindows/PerPixelTranslucentSwing.java
    is wrong
    + S8190891: Clean up G1 barrier code in compiler interface (ci)
    + S8190911: tools/jdeps/MultiReleaseJar.java failed with
    java.lang.IllegalThreadStateException
    + S8190925: Deprecate FastTLABRefill and set default off
    + S8190939: JShell: gives a compiler error evaluating an
    expression of inaccessible type
    + S8190975: [Graal] Tests which run with "--limit-modules
    java.base" could fail when Graal is used as JIT
    + S8191042: Deprecate VM option CheckEndorsedAndExtDirs
    + S8191049: Add alternate version of pns() that is callable from
    within hotspot source
    + S8191069: Miscellaneous changes imported from jsr166 CVS
    2017-12
    + S8191132: assert condition should not be in quotes
    + S8191173: (cl) Clarify or remove "for delegation" in
    ClassLoader spec
    + S8191203: Remove duplicated jimage.hpp
    + S8191205: Set native-debug-symbols default to "external"
    + S8191212: AIX: Build and polling page allocation broken after
    8189941
    + S8191234: TypeKindVisitor needs to handle modules
    + S8191313: compiler/runtime/SpreadNullArg.java fails in tier1
    + S8191315: Add
    serviceability/sa/TestRevPtrsForInvokeDynamic.java to
    ProblemList.txt
    + S8191326: Deprecate SafepointSpinBeforeYield
    + S8191327: Deprecate DeferThrSuspendLoopCount
    + S8191329: Deprecate DeferPollingPageLoopCount
    + S8191333: Zero variant broken after 8189941
    + S8191337: GCC 4.8 build broken after 8186571
    + S8191338: aarch64: fails to build after 8189745
    + S8191370: Add serviceability agent tests to tier1
    + S8191373: Multiple NUMA nodes expected
    + S8191384: WaveFloatFileReader never closes the data stream
    + S8191401: [TESTBUG] serviceability/sa/ClhsdbFlags.java can
    fail due to UseJVMCICompiler
    + S8191404: Upgrading JDK with latest available LSR data from
    IANA.
    + S8191424: Missing include in gcArguments.cpp
    + S8191428: Regression: Swing button label wrapping with hidpi
    + S8191431: Reading multiple PNG images with unique IDAT chunk
    positions will cause IIOException
    + S8191439: Race in building jdk.rmic.interim
    + S8191516: OutputStream.write(byte[],int,int) could have fewer
    parameter bounds checks
    + S8191562: Missing include in gcArguments.cpp breaks minimal
    JVM build
    + S8191580: open/test/hotspot/jtreg/runtime/LoadClass/TestResize
    fails on product build
    + S8191615: LogCompilation can show bytes
    + S8191616: [TEST_BUG] :
    sanity/client/SwingSet/src/SliderDemoTest.java: Failed with
    TimeoutExpiredException: Wait "Wait till Slider attains the
    specified state."
    + S8191631: Problem list jdk/jshell/StartOptionTest.java,
    jdk/jshell/ToolProviderTest.java and
    jdk/jshell/ExternalEditorTest.java temporarily
    + S8191653: Test failures in BootAppendTests - missing
    jdk.internal.vm.compiler module
    + S8191663: Zero variant broken after 8189170 and 8189871
    + S8191678: [TESTBUG] Add keyword headful in java/awt and javax
    tests.
    + S8191688: Assert failed in > 200 tests: failed dependencies,
    but counter didn't change
    + S8191707: Options with invalid values are incorrectly treated
    as obsolete and ignored
    + S8191715: Update documentation pointing to "common" directory
    + S8191736: replace javah w/ javac in jdk tests
    + S8191739: [TESTBUG]
    test/hotspot/jtreg/runtime/LoadClass/TestResize.java fails to
    compile after JDK-8191580
    + S8191771: nashorn ant makefile uses javadoc -link which may
    fail
    + S8191802: Upward projection result is A<? extends Number>
    instead of A<? super Integer>
    + S8191810: jjs should avoid hard coded javadoc base url for
    shift-tab documentation feature
    + S8191819: String.prototype.match should follow ES6
    specification
    + S8191820: Fix run-test jtreg test selection and component
    calculation
    + S8191834: Assigning a void expression to a "var" crashes the
    compiler
    + S8191856: "make clean-test" does not work properly
    + S8191878: Reduce code duplication in BeanLinker
    + S8191891: Update minumum Ant version in Nashorn build.xml
    + S8191918: tomcat gzip-compressed response bodies appear to be
    broken in update 151
    + S8191923: Save run-test summary to file
    + S8191933: Use failure handler in run-test
    + S8191937: Lost interrupt in AbstractQueuedSynchronizer when
    tryAcquire methods throw
    + S8191938: Fix lint warnings in JAXP repo: a few Deprecation
    warnings and enable -Xlint:all
    + S8191942: Replace jdeps use of
    jdk.internal.util.jar.VersionedStream with new public API
    + S8191955: AArch64: incorrect prefetch distance causes an
    internal error
    + S8191981: javac crash when detecting lambda candidates
    + S8192067: Add fixpath to test image
    + S8192771: Boot JDK jar tool used to construct the modular JAR
    for java.jnlp
    + S8192781: tools/jar/multiRelease/Basic.java test
    Basic.test09(): failure after change d34958
    + S8192816: Let run-test save exit code
    + S8192854: FONTCONFIG_CFLAGS missing from spec.gmk.in
    + S8192876: MacOS build fails intermittently after JDK-8139653
    + S8192879: jdk.internal.util.jar.VersionedStream is no longer
    needed
    + S8192885: Compiler in JDK 10-ea+33 misses to include entry in
    LineNumberTable for goto instruction of foreach loop
    + S8192892: Improve JrtPath::getResolved fast-path test
    + S8192958: TEST.groups, group jdk_util_other:file not found:
    jdk/internal/uti
    + S8192961: Remove some double semicolons
    + S8192973: Adding "Module Resolution" to javadoc search index
    + S8192995: run-test gtest should use all jvm variants, not just
    "server"
    + S8193014: Add "special" tests to run-test to cover odd cases
    + S8193055: ADD_JVM_ARG_IF_OK always fails
    + S8193060: Set MAKE env variable in jib profile for gnumake
    + S8193061: Add run-test-prebuilt functionality
    + S8193064: JarFile::getEntry0 method reference use cause for
    startup regression
- Added patch:
  * linux_chroot_crash.patch
    + upstream fix for: "S8192154: JVM crashes inside some chroot
    environments on linux"
* Thu Dec  7 2017 fstrba@suse.com
- The macro bits was not defined for aarch64 and some other
  architectures (bsc#1071624)
* Fri Dec  1 2017 fstrba@suse.com
- Run TestCryptoLevel and TestECDSA as a part of build to assure
  that the crypto works as expected
* Fri Dec  1 2017 w01dnick@gmail.com
- Added patch:
  * java10-improved-fonts.patch
    + Imports IMPROVED_FONT_RENDERING from OpenJDK 1.8.0 to use
    system fontconfig settings instead of hardcoded flags
    + Adds fontconfig dependency
- Enabled IMPROVED_FONT_RENDERING
* Thu Nov 23 2017 fstrba@suse.com
- Update to upstream tag jdk-10+33
* Tue Nov 21 2017 fstrba@suse.com
- Update to upstream tag jdk-10+32
* Wed Nov 15 2017 fstrba@suse.com
- Make alternative priority 2005 instead of 0. Like that jdk10 will
  have priority over jdk9 if installed.
* Fri Nov 10 2017 fstrba@suse.com
- Update to upstream tag jdk-10+31
* Thu Nov  9 2017 fstrba@suse.com
- Modified patch:
  * jaw-misc.patch
    + Do not look for gdk-3.0, since we are building against gtk2
- Added patch:
  * icedtea-sound-soundproperties.patch
    + Even though we build the pulseaudio plugin, disable it by
    default in the configuration file, since the internal openjdk
    provider is reputed to be better
* Mon Nov  6 2017 fstrba@suse.com
- Removed patch:
  * load_java_atk_wrapper.patch
    + Give up this approach that requires patching of class loaders
- Build java-atk-wrapper as a modular jar inside the OpenJDK build
- Added patches:
  * jaw-misc.patch
    + Fix some build issues and add the manifest.txt that is not
    not distributed by mistake
  * jaw-jdk10.patch
    + Make java-atk-wrapper a java module that implements the
    javax.accessibility.AccessibilityProvider interface
* Fri Nov  3 2017 fstrba@suse.com
- Update to upstream tag jdk-10+30
- Packaging improvements:
  * add all binaries in JAVA_HOME/bin to alternatives in order to
    have them in the system binary path when this alternative is
    chosen
* Thu Nov  2 2017 fstrba@suse.com
- Add back the icedtea-sound plugin and integrate it into the
  system modules
- Added patch:
  * icedtea-sound-1.0.1-jdk9.patch
    + make icedtea-sound.jar modular for jdk9
- Clean some conditionals for very old %%%%suse_version
* Thu Nov  2 2017 fstrba@suse.com
- Modified patch
  * alternative-tzdb_dat.patch
    + Place the tz.properties file to JAVA_HOME/conf where OpenJDK9
    expects to have the configuration files
    + Patch also the other place in jdk that loads the tzdb.dat
    file
* Fri Oct 27 2017 fstrba@suse.com
- Update to upstream tag jdk-10+29
* Thu Oct 26 2017 fstrba@suse.com
- Update to upstream tag jdk-10+28
- Allow bootstrapping with jdk9 or jdk10, since the capacity to
  use jdk8 is removed upstream
- Added patch:
  * load_java_atk_wrapper.patch
    + put jar that is specified in accessibility.properties file in
    assistive_technologies.classpath property on the class path
* Fri Oct 13 2017 fstrba@suse.com
- Update to upstream tag jdk-10+26
- Use the new monolithical jdk10/master repository
- Make the conditions for aot a bit more readable
- Fix javaver macro to output 10 instead of 1.10.0
- For accessibility subpackage, try to copy Oracle Java as to the
  places of *.properties files and *.jar files.
* Thu Sep 21 2017 fstrba@suse.com
- Update the provided jdbc-stdext version to 4.3
- Build jaotc on supported platform
- Package the jmod files as a separate %%{name}-jmod package
* Thu Sep 21 2017 fstrba@suse.com
- Update to ustream tag jdk-10+23
- Allow bootstrapping with any of jdk 8, 9 or 10
* Thu Aug 31 2017 fstrba@suse.com
- Added patch:
  * ppc32-atomic_copy64.patch
  - fix in a zero assembly for PPC that prevented 32-bit ppc
    build to succeed
- Removed patch:
  * 8073754-stack-overflow-9-build.patch
  - rendered unnecessary by the above
- Minor packaging fixes for zero build architectures
* Thu Aug 24 2017 fstrba@suse.com
- Package the conf directories in jre and jdk. Fixes bsc#1047842.
* Wed Aug 23 2017 fstrba@suse.com
- Update to ustream tag jdk-10+20
- Added patches:
  * java-10-openjdk-linuxfilestore.patch
  - Fix bsc#1032647, bsc#1052009 with btrfs subvolumes and
    overlayfs
  * 8073754-stack-overflow-9-build.patch
  - Fix stack overflows in ppc build
* Mon Jul 24 2017 fstrba@suse.com
- Update to upstream tag jdk-10+16
* Tue Jul 18 2017 fstrba@suse.com
- Update to upstream tag jdk-10+15
* Fri Jun 30 2017 fstrba@suse.com
- Update to upstream tag jdk-10+13
- Remove patch:
  * java-10-openjdk-minmax.patch
    + fixed upstream
* Fri Jun  9 2017 fstrba@suse.com
- Update to upstream tag jdk-10+10
* Sun May 28 2017 fstrba@suse.com
- Update to upstream tag jdk-10+9
* Tue May 16 2017 fstrba@suse.com
- Update to upstream tag jdk-10+6
* Wed May  3 2017 fstrba@suse.com
- Update to upstream tag jdk-10+5
* Tue May  2 2017 fstrba@suse.com
- Update to upstream tag jdk-10+2
* Wed Apr 26 2017 fstrba@suse.com
- Update to upstream tag jdk-10+1
* Fri Apr  7 2017 fstrba@suse.com
- Initial commit for really really early proof of concept
